diff --git a/htdocs/admin/prelevement.php b/htdocs/admin/prelevement.php
index 119bfbb0cd2..db907e34ec0 100644
--- a/htdocs/admin/prelevement.php
+++ b/htdocs/admin/prelevement.php
@@ -168,9 +168,12 @@ if ($conf->global->MAIN_MODULE_NOTIFICATION)
$db->free($resql);
}
- $sql = "SELECT rowid, code, titre";
- $sql.= " FROM ".MAIN_DB_PREFIX."action_def";
- $sql.= " WHERE objet_type = 'withdraw'";
+ $sql = "SELECT rowid, code, label";
+ $sql.= " FROM ".MAIN_DB_PREFIX."c_action_trigger";
+ $sql.= " WHERE elementtype = 'withdraw'";
+ $sql.= " AND entity = ".$conf->entity;
+ $sql.= " AND active = 1";
+
$resql = $db->query($sql);
if ($resql)
{
@@ -180,7 +183,7 @@ if ($conf->global->MAIN_MODULE_NOTIFICATION)
while ($i < $num)
{
$obj = $db->fetch_object($resql);
- $label=($langs->trans("Notify_".$obj->code)!="Notify_".$obj->code?$langs->trans("Notify_".$obj->code):$obj->titre);
+ $label=($langs->trans("Notify_".$obj->code)!="Notify_".$obj->code?$langs->trans("Notify_".$obj->code):$obj->label);
$actions[$obj->rowid]=$label;
$i++;
}
@@ -209,13 +212,14 @@ if ($conf->global->MAIN_MODULE_NOTIFICATION)
}
// List of current notifications for objet_type='withdraw'
$sql = "SELECT u.name, u.firstname";
-$sql.= ", nd.rowid, ad.code, ad.titre";
+$sql.= ", nd.rowid, ad.code, ad.label";
$sql.= " FROM ".MAIN_DB_PREFIX."user as u";
$sql.= ", ".MAIN_DB_PREFIX."notify_def as nd";
-$sql.= ", ".MAIN_DB_PREFIX."action_def as ad";
-$sql.= " WHERE u.rowid = nd.fk_user AND nd.fk_action = ad.rowid";
-$sql.= " AND ad.objet_type = 'withdraw'";
+$sql.= ", ".MAIN_DB_PREFIX."c_action_trigger as ad";
+$sql.= " WHERE u.rowid = nd.fk_user";
+$sql.= " AND nd.fk_action = ad.rowid";
$sql.= " AND u.entity IN (0,".$conf->entity.")";
+
$resql = $db->query($sql);
if ($resql)
{
@@ -229,7 +233,7 @@ if ($resql)
print "
";
print '| '.$obj->firstname." ".$obj->name.' | ';
- $label=($langs->trans("Notify_".$obj->code)!="Notify_".$obj->code?$langs->trans("Notify_".$obj->code):$obj->titre);
+ $label=($langs->trans("Notify_".$obj->code)!="Notify_".$obj->code?$langs->trans("Notify_".$obj->code):$obj->label);
print ''.$label.' | ';
print 'rowid.'">'.img_delete().' | ';
print '
';
diff --git a/htdocs/install/mysql/data/llx_action_def.sql b/htdocs/install/mysql/data/llx_action_def.sql
deleted file mode 100644
index 403c69f9ac2..00000000000
--- a/htdocs/install/mysql/data/llx_action_def.sql
+++ /dev/null
@@ -1,44 +0,0 @@
--- Copyright (C) 2001-2004 Rodolphe Quiedeville
--- Copyright (C) 2003 Jean-Louis Bergamo
--- Copyright (C) 2004-2009 Laurent Destailleur
--- Copyright (C) 2004 Benoit Mortier
--- Copyright (C) 2004 Guillaume Delecourt
--- Copyright (C) 2005-2009 Regis Houssin
--- Copyright (C) 2007 Patrick Raguin
--- Copyright (C) 2010 Juanjo Menent
---
--- This program is free software; you can redistribute it and/or modify
--- it under the terms of the GNU General Public License as published by
--- the Free Software Foundation; either version 2 of the License, or
--- (at your option) any later version.
---
--- This program is distributed in the hope that it will be useful,
--- but WITHOUT ANY WARRANTY; without even the implied warranty of
--- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
--- GNU General Public License for more details.
---
--- You should have received a copy of the GNU General Public License
--- along with this program; if not, write to the Free Software
--- Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
---
--- $Id$
---
-
---
--- Ne pas placer de commentaire en fin de ligne, ce fichier est parsé lors
--- de l'install et tous les sigles '--' sont supprimés.
---
-
---
--- Définition des actions de workflow notifications
---
-delete from llx_action_def;
-insert into llx_action_def (rowid,code,titre,description,objet_type) values (1,'NOTIFY_VAL_FICHINTER','Validation fiche intervention','Executed when a intervention is validated','ficheinter');
-insert into llx_action_def (rowid,code,titre,description,objet_type) values (2,'NOTIFY_VAL_FAC','Validation facture client','Executed when a customer invoice is approved','facture');
-insert into llx_action_def (rowid,code,titre,description,objet_type) values (3,'NOTIFY_APP_ORDER_SUPPLIER','Approbation commande fournisseur','Executed when a supplier order is approved','order_supplier');
-insert into llx_action_def (rowid,code,titre,description,objet_type) values (4,'NOTIFY_REF_ORDER_SUPPLIER','Refus commande fournisseur','Executed when a supplier order is refused','order_supplier');
-insert into llx_action_def (rowid,code,titre,description,objet_type) values (5,'NOTIFY_VAL_ORDER','Validation commande client','Executed when a customer order is validated','order');
-insert into llx_action_def (rowid,code,titre,description,objet_type) values (6,'NOTIFY_VAL_PROPAL','Validation proposition client','Executed when a commercial proposal is validated','propal');
-insert into llx_action_def (rowid,code,titre,description,objet_type) values (7,'NOTIFY_TRN_WITHDRAW','Transmission prélèvement','Executed when a withdrawal is transmited','withdraw');
-insert into llx_action_def (rowid,code,titre,description,objet_type) values (8,'NOTIFY_CRD_WITHDRAW','Créditer prélèvement','Executed when a withdrawal is credited','withdraw');
-insert into llx_action_def (rowid,code,titre,description,objet_type) values (9,'NOTIFY_EMT_WITHDRAW','Emission prélèvement','Executed when a withdrawal is emited','withdraw');
diff --git a/htdocs/install/mysql/data/llx_c_action_trigger.sql b/htdocs/install/mysql/data/llx_c_action_trigger.sql
new file mode 100644
index 00000000000..2ca456cdf92
--- /dev/null
+++ b/htdocs/install/mysql/data/llx_c_action_trigger.sql
@@ -0,0 +1,44 @@
+-- Copyright (C) 2001-2004 Rodolphe Quiedeville
+-- Copyright (C) 2003 Jean-Louis Bergamo
+-- Copyright (C) 2004-2011 Laurent Destailleur
+-- Copyright (C) 2004 Benoit Mortier
+-- Copyright (C) 2004 Guillaume Delecourt
+-- Copyright (C) 2005-2011 Regis Houssin
+-- Copyright (C) 2007 Patrick Raguin
+-- Copyright (C) 2010 Juanjo Menent
+--
+-- This program is free software; you can redistribute it and/or modify
+-- it under the terms of the GNU General Public License as published by
+-- the Free Software Foundation; either version 2 of the License, or
+-- (at your option) any later version.
+--
+-- This program is distributed in the hope that it will be useful,
+-- but WITHOUT ANY WARRANTY; without even the implied warranty of
+-- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+-- GNU General Public License for more details.
+--
+-- You should have received a copy of the GNU General Public License
+-- along with this program; if not, write to the Free Software
+-- Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+--
+-- $Id$
+--
+
+--
+-- Ne pas placer de commentaire en fin de ligne, ce fichier est parsé lors
+-- de l'install et tous les sigles '--' sont supprimés.
+--
+
+--
+-- Définition des actions de workflow
+--
+delete from llx_c_action_trigger;
+insert into llx_c_action_trigger (rowid,code,label,description,elementtype) values (1,'FICHEINTER_VALIDATE','Validation fiche intervention','Executed when a intervention is validated','ficheinter');
+insert into llx_c_action_trigger (rowid,code,label,description,elementtype) values (2,'BILL_VALIDATE','Validation facture client','Executed when a customer invoice is approved','facture');
+insert into llx_c_action_trigger (rowid,code,label,description,elementtype) values (3,'ORDER_SUPPLIER_APPROVE','Approbation commande fournisseur','Executed when a supplier order is approved','order_supplier');
+insert into llx_c_action_trigger (rowid,code,label,description,elementtype) values (4,'ORDER_SUPPLIER_REFUSE','Refus commande fournisseur','Executed when a supplier order is refused','order_supplier');
+insert into llx_c_action_trigger (rowid,code,label,description,elementtype) values (5,'ORDER_VALIDATE','Validation commande client','Executed when a customer order is validated','order');
+insert into llx_c_action_trigger (rowid,code,label,description,elementtype) values (6,'PROPAL_VALIDATE','Validation proposition client','Executed when a commercial proposal is validated','propal');
+insert into llx_c_action_trigger (rowid,code,label,description,elementtype) values (7,'WITHDRAW_TRANSMIT','Transmission prélèvement','Executed when a withdrawal is transmited','withdraw');
+insert into llx_c_action_trigger (rowid,code,label,description,elementtype) values (8,'WITHDRAW_CREDIT','Créditer prélèvement','Executed when a withdrawal is credited','withdraw');
+insert into llx_c_action_trigger (rowid,code,label,description,elementtype) values (9,'WITHDRAW_EMIT','Emission prélèvement','Executed when a withdrawal is emited','withdraw');
diff --git a/htdocs/install/mysql/migration/3.0.0-3.1.0.sql b/htdocs/install/mysql/migration/3.0.0-3.1.0.sql
index b426f291ed3..a76f1e1dd67 100755
--- a/htdocs/install/mysql/migration/3.0.0-3.1.0.sql
+++ b/htdocs/install/mysql/migration/3.0.0-3.1.0.sql
@@ -140,6 +140,31 @@ ALTER TABLE llx_actioncomm ADD COLUMN entity integer DEFAULT 1 NOT NULL AFTER id
ALTER TABLE llx_actioncomm ADD COLUMN fk_element integer DEFAULT NULL AFTER note;
ALTER TABLE llx_actioncomm ADD COLUMN elementtype varchar(16) DEFAULT NULL AFTER fk_element;
+create table llx_c_action_trigger
+(
+ rowid integer AUTO_INCREMENT PRIMARY KEY,
+ entity integer DEFAULT 1 NOT NULL,
+ code varchar(32) NOT NULL,
+ label varchar(128) NOT NULL,
+ description varchar(255),
+ elementtype varchar(16) NOT NULL,
+ active tinyint DEFAULT 1 NOT NULL,
+ rang integer DEFAULT 0
+
+)ENGINE=innodb;
+
+INSERT INTO llx_c_action_trigger (rowid,code,label,description,elementtype) VALUES (1,'FICHEINTER_VALIDATE','Validation fiche intervention','Executed when a intervention is validated','ficheinter');
+INSERT INTO llx_c_action_trigger (rowid,code,label,description,elementtype) VALUES (2,'BILL_VALIDATE','Validation facture client','Executed when a customer invoice is approved','facture');
+INSERT INTO llx_c_action_trigger (rowid,code,label,description,elementtype) VALUES (3,'ORDER_SUPPLIER_APPROVE','Approbation commande fournisseur','Executed when a supplier order is approved','order_supplier');
+INSERT INTO llx_c_action_trigger (rowid,code,label,description,elementtype) VALUES (4,'ORDER_SUPPLIER_REFUSE','Refus commande fournisseur','Executed when a supplier order is refused','order_supplier');
+INSERT INTO llx_c_action_trigger (rowid,code,label,description,elementtype) VALUES (5,'ORDER_VALIDATE','Validation commande client','Executed when a customer order is validated','order');
+INSERT INTO llx_c_action_trigger (rowid,code,label,description,elementtype) VALUES (6,'PROPAL_VALIDATE','Validation proposition client','Executed when a commercial proposal is validated','propal');
+INSERT INTO llx_c_action_trigger (rowid,code,label,description,elementtype) VALUES (7,'WITHDRAW_TRANSMIT','Transmission prélèvement','Executed when a withdrawal is transmited','withdraw');
+INSERT INTO llx_c_action_trigger (rowid,code,label,description,elementtype) VALUES (8,'WITHDRAW_CREDIT','Créditer prélèvement','Executed when a withdrawal is credited','withdraw');
+INSERT INTO llx_c_action_trigger (rowid,code,label,description,elementtype) VALUES (9,'WITHDRAW_EMIT','Emission prélèvement','Executed when a withdrawal is emited','withdraw');
+
+DROP table llx_action_def;
+
--Add Chile data (id pays=67)
-- Regions Chile
INSERT INTO llx_c_regions (rowid, code_region, fk_pays, cheflieu, tncc, nom, active) VALUES (6701, 6701, 67, NULL, NULL, 'Tarapacá', 1);
diff --git a/htdocs/install/mysql/tables/llx_c_action_trigger.key.sql b/htdocs/install/mysql/tables/llx_c_action_trigger.key.sql
new file mode 100644
index 00000000000..d6b39ea5831
--- /dev/null
+++ b/htdocs/install/mysql/tables/llx_c_action_trigger.key.sql
@@ -0,0 +1,22 @@
+-- ============================================================================
+-- Copyright (C) 2011 Regis Houssin
+--
+-- This program is free software; you can redistribute it and/or modify
+-- it under the terms of the GNU General Public License as published by
+-- the Free Software Foundation; either version 2 of the License, or
+-- (at your option) any later version.
+--
+-- This program is distributed in the hope that it will be useful,
+-- but WITHOUT ANY WARRANTY; without even the implied warranty of
+-- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+-- GNU General Public License for more details.
+--
+-- You should have received a copy of the GNU General Public License
+-- along with this program; if not, write to the Free Software
+-- Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+--
+-- $Id$
+-- ============================================================================
+
+
+ALTER TABLE llx_c_action_trigger ADD UNIQUE INDEX uk_action_trigger_code (entity, code);
diff --git a/htdocs/install/mysql/tables/llx_action_def.sql b/htdocs/install/mysql/tables/llx_c_action_trigger.sql
similarity index 65%
rename from htdocs/install/mysql/tables/llx_action_def.sql
rename to htdocs/install/mysql/tables/llx_c_action_trigger.sql
index 530051af7d9..24b44f5081c 100644
--- a/htdocs/install/mysql/tables/llx_action_def.sql
+++ b/htdocs/install/mysql/tables/llx_c_action_trigger.sql
@@ -1,7 +1,5 @@
-- ===================================================================
--- Copyright (C) 2003 Rodolphe Quiedeville
--- Copyright (C) 2004 Benoit Mortier
--- Copyright (C) 2004 Guillaume Delecourt
+-- Copyright (C) 2011 Regis Houssin
--
-- This program is free software; you can redistribute it and/or modify
-- it under the terms of the GNU General Public License as published by
@@ -20,12 +18,15 @@
-- $Id$
-- ===================================================================
-create table llx_action_def
+create table llx_c_action_trigger
(
- rowid integer NOT NULL PRIMARY KEY,
- code varchar(32) UNIQUE NOT NULL,
- tms timestamp,
- titre varchar(255) NOT NULL,
- description text,
- objet_type varchar(16) NOT NULL
+ rowid integer AUTO_INCREMENT PRIMARY KEY,
+ entity integer DEFAULT 1 NOT NULL,
+ code varchar(32) NOT NULL,
+ label varchar(128) NOT NULL,
+ description varchar(255),
+ elementtype varchar(16) NOT NULL,
+ active tinyint DEFAULT 1 NOT NULL,
+ rang integer DEFAULT 0
+
)ENGINE=innodb;
diff --git a/htdocs/langs/ar_SA/other.lang b/htdocs/langs/ar_SA/other.lang
index d55514ac24b..b2ff1cbc493 100755
--- a/htdocs/langs/ar_SA/other.lang
+++ b/htdocs/langs/ar_SA/other.lang
@@ -35,10 +35,10 @@ BirthdayDate=عيد ميلاد
DateToBirth=تاريخ الميلاد
BirthdayAlertOn=عيد ميلاد النشطة في حالة تأهب
BirthdayAlertOff=عيد الميلاد فى حالة تأهب الخاملة
-Notify_NOTIFY_VAL_FICHINTER=تدخل المصادق
-Notify_NOTIFY_VAL_FAC=فاتورة مصادق
-Notify_NOTIFY_APP_ORDER_SUPPLIER=من أجل الموافقة على المورد
-Notify_NOTIFY_REF_ORDER_SUPPLIER=من أجل رفض الموردين
+Notify_FICHINTER_VALIDATE=تدخل المصادق
+Notify_BILL_VALIDATE=فاتورة مصادق
+Notify_ORDER_SUPPLIER_APPROVE=من أجل الموافقة على المورد
+Notify_ORDER_SUPPLIER_REFUSE=من أجل رفض الموردين
NbOfAttachedFiles=عدد الملفات المرفقة / وثائق
TotalSizeOfAttachedFiles=اجمالى حجم الملفات المرفقة / وثائق
MaxSize=الحجم الأقصى
@@ -187,8 +187,8 @@ NumberOfUnitsProposals=عدد من الوحدات على مقترحات بشأن
// START - Lines generated via autotranslator.php tool (2010-07-17 11:16:46).
// Reference language: en_US
-Notify_NOTIFY_VAL_ORDER=التحقق من صحة النظام العميل
-Notify_NOTIFY_VAL_PROPAL=التحقق من صحة اقتراح العملاء
+Notify_ORDER_VALIDATE=التحقق من صحة النظام العميل
+Notify_PROPAL_VALIDATE=التحقق من صحة اقتراح العملاء
PredefinedMailTest=هذا هو الاختبار الإلكتروني. تكون مفصولة \ nThe سطرين من قبل حرف إرجاع.
PredefinedMailTestHtml=هذا هو البريد الاختبار (الاختبار يجب أن تكون في كلمة جريئة).
وتفصل بين الخطين من قبل حرف إرجاع.
CalculatedWeight=يحسب الوزن
diff --git a/htdocs/langs/ca_ES/other.lang b/htdocs/langs/ca_ES/other.lang
index 4754626b929..e578a7f2bfb 100644
--- a/htdocs/langs/ca_ES/other.lang
+++ b/htdocs/langs/ca_ES/other.lang
@@ -26,15 +26,15 @@ BirthdayDate=Data aniversari
DateToBirth=Data de naiximent
BirthdayAlertOn=alerta aniversari activada
BirthdayAlertOff=alerta aniversari desactivada
-Notify_NOTIFY_VAL_FICHINTER=Validació fitxa intervenció
-Notify_NOTIFY_VAL_FAC=Validació factura
-Notify_NOTIFY_APP_ORDER_SUPPLIER=Aprovació comanda a proveïdor
-Notify_NOTIFY_REF_ORDER_SUPPLIER=Rebuig comanda a proveïdor
-Notify_NOTIFY_VAL_ORDER=Validació comanda client
-Notify_NOTIFY_VAL_PROPAL=Validació pressupost client
-Notify_NOTIFY_TRN_WITHDRAW=Transmissió domiciliació
-Notify_NOTIFY_CRD_WITHDRAW=Abonament domiciliació
-Notify_NOTIFY_EMT_WITHDRAW=Emissió domiciliació
+Notify_FICHINTER_VALIDATE=Validació fitxa intervenció
+Notify_BILL_VALIDATE=Validació factura
+Notify_ORDER_SUPPLIER_APPROVE=Aprovació comanda a proveïdor
+Notify_ORDER_SUPPLIER_REFUSE=Rebuig comanda a proveïdor
+Notify_ORDER_VALIDATE=Validació comanda client
+Notify_PROPAL_VALIDATE=Validació pressupost client
+Notify_WITHDRAW_TRANSMIT=Transmissió domiciliació
+Notify_WITHDRAW_CREDIT=Abonament domiciliació
+Notify_WITHDRAW_EMIT=Emissió domiciliació
NbOfAttachedFiles=Número arxius/documents adjunts
TotalSizeOfAttachedFiles=Mida total dels arxius/documents adjunts
MaxSize=Tamany màxim
diff --git a/htdocs/langs/da_DK/other.lang b/htdocs/langs/da_DK/other.lang
index 5a4c9034857..6f4acf9483c 100755
--- a/htdocs/langs/da_DK/other.lang
+++ b/htdocs/langs/da_DK/other.lang
@@ -35,8 +35,8 @@ Tools=Værktøj
Birthday=Fødselsdag
BirthdayDate=Fødselsdag
DateToBirth=Dato for fødsel
-Notify_NOTIFY_VAL_FICHINTER=Valider intervention
-Notify_NOTIFY_VAL_FAC=Valider regningen
+Notify_FICHINTER_VALIDATE=Valider intervention
+Notify_BILL_VALIDATE=Valider regningen
NbOfAttachedFiles=Antal vedhæftede filer / dokumenter
TotalSizeOfAttachedFiles=Samlede størrelse på vedhæftede filer / dokumenter
MaxSize=Maksimumstørrelse
@@ -162,8 +162,8 @@ NewExport=Nye eksportmarkeder
// Reference language: en_US
BirthdayAlertOn=fødselsdag alarm aktive
BirthdayAlertOff=fødselsdag alarm inaktive
-Notify_NOTIFY_APP_ORDER_SUPPLIER=Leverandør for godkendt
-Notify_NOTIFY_REF_ORDER_SUPPLIER=Leverandør For nægtes
+Notify_ORDER_SUPPLIER_APPROVE=Leverandør for godkendt
+Notify_ORDER_SUPPLIER_REFUSE=Leverandør For nægtes
DemoDesc=Dolibarr er et kompakt ERP / CRM sammensat af flere funktionelle moduler. En demo, som omfatter alle moduler ikke betyder noget, da dette aldrig sker. Så flere demo profiler der er tilgængelige.
DemoCompanyServiceOnly=Administrer en freelance virksomhed sælger service kun
SendNewPasswordDesc=Denne form giver dig mulighed for at anmode om en ny adgangskode. Det vil blive sendt til din email-adresse.
Ændring vil kun være effektiv, når de har klikket på bekræftelse linket i denne e-mail.
Tjek din e-mail reader software.
@@ -183,8 +183,8 @@ DemoFundation2=Administrer medlemmer og bankkonto i en fond
// START - Lines generated via autotranslator.php tool (2010-07-17 11:19:38).
// Reference language: en_US
-Notify_NOTIFY_VAL_ORDER=Kundeordre valideret
-Notify_NOTIFY_VAL_PROPAL=Kunde forslag valideret
+Notify_ORDER_VALIDATE=Kundeordre valideret
+Notify_PROPAL_VALIDATE=Kunde forslag valideret
PredefinedMailTest=Dette er en test mail. \ NDen to linjer er adskilt af et linjeskift.
PredefinedMailTestHtml=Dette er en test mail (ordet test skal være i fed).
De to linjer er adskilt af et linjeskift.
CalculatedWeight=Beregnet vægt
diff --git a/htdocs/langs/de_AT/other.lang b/htdocs/langs/de_AT/other.lang
index 5ead350d60e..f2120206b94 100755
--- a/htdocs/langs/de_AT/other.lang
+++ b/htdocs/langs/de_AT/other.lang
@@ -30,8 +30,8 @@ Tools=Werkzeuge
Birthday=Geburtstag
BirthdayDate=Geburtstag
DateToBirth=Geburtstdatum
-Notify_NOTIFY_VAL_FICHINTER=Eingriff freigegeben
-Notify_NOTIFY_VAL_FAC=Rechnung freigegeben
+Notify_FICHINTER_VALIDATE=Eingriff freigegeben
+Notify_BILL_VALIDATE=Rechnung freigegeben
NbOfAttachedFiles=Anzahl der angehängten Dateien/okumente
TotalSizeOfAttachedFiles=Gesamtgröße der angehängten Dateien/Dokumente
MaxSize=Maximalgröße
@@ -154,8 +154,8 @@ NewExport=Neuer Export
BirthdayAlertOn=Geburtstagserinnerung EIN
BirthdayAlertOff=Geburtstagserinnerung AUS
-Notify_NOTIFY_APP_ORDER_SUPPLIER=Lieferantenbestellung freigegeben
-Notify_NOTIFY_REF_ORDER_SUPPLIER=Lieferantenbestellung abgelehnt
+Notify_ORDER_SUPPLIER_APPROVE=Lieferantenbestellung freigegeben
+Notify_ORDER_SUPPLIER_REFUSE=Lieferantenbestellung abgelehnt
DemoDesc=Bei Dolibarr handelt es sich um ein kompaktes ERP/CRM-System, bestehend aus einzelnen Modulen. Da eine Demo aller Module kaum eine praxisnahe Anwendung darstellt, stehen Ihnen unterschiedliche Demo-Profile zur Verfügung.
SendNewPasswordDesc=Über dieses Formular können Sie sich ein neues Passwort zusenden lassen.
Die Änderungen an Ihrem Passwort werden erst wirksam, wenn Sie auf den im Mail enthaltenen Bestätigungslink klicken.
Überprüfen Sie den Posteingang Ihrer E-Mail-Anwendung.
EMailTextInterventionValidated=Eingriff %s freigegeben
@@ -163,8 +163,8 @@ EMailTextInvoiceValidated=Rechnung %s freigegeben
ImportedWithSet=Import Datensatz
DolibarrNotification=Automatische Benachrichtigung
-Notify_NOTIFY_VAL_ORDER=Kundenbestellung freigegeben
-Notify_NOTIFY_VAL_PROPAL=Angebot freigegeben
+Notify_ORDER_VALIDATE=Kundenbestellung freigegeben
+Notify_PROPAL_VALIDATE=Angebot freigegeben
PredefinedMailTest=Dies ist ein Test-Mail.\n Die beiden Zeilen sind durch eine Zeilenschaltung getrennt.
PredefinedMailTestHtml=Dies ist ein (HTML)-Test Mail (das Wort Test muss in Fettschrift erscheinen).
Die beiden Zeilen sollteb durch eine Zeilenschaltung getrennt sein.
CalculatedWeight=Errechnetes Gewicht
diff --git a/htdocs/langs/de_DE/other.lang b/htdocs/langs/de_DE/other.lang
index 5ead350d60e..f2120206b94 100644
--- a/htdocs/langs/de_DE/other.lang
+++ b/htdocs/langs/de_DE/other.lang
@@ -30,8 +30,8 @@ Tools=Werkzeuge
Birthday=Geburtstag
BirthdayDate=Geburtstag
DateToBirth=Geburtstdatum
-Notify_NOTIFY_VAL_FICHINTER=Eingriff freigegeben
-Notify_NOTIFY_VAL_FAC=Rechnung freigegeben
+Notify_FICHINTER_VALIDATE=Eingriff freigegeben
+Notify_BILL_VALIDATE=Rechnung freigegeben
NbOfAttachedFiles=Anzahl der angehängten Dateien/okumente
TotalSizeOfAttachedFiles=Gesamtgröße der angehängten Dateien/Dokumente
MaxSize=Maximalgröße
@@ -154,8 +154,8 @@ NewExport=Neuer Export
BirthdayAlertOn=Geburtstagserinnerung EIN
BirthdayAlertOff=Geburtstagserinnerung AUS
-Notify_NOTIFY_APP_ORDER_SUPPLIER=Lieferantenbestellung freigegeben
-Notify_NOTIFY_REF_ORDER_SUPPLIER=Lieferantenbestellung abgelehnt
+Notify_ORDER_SUPPLIER_APPROVE=Lieferantenbestellung freigegeben
+Notify_ORDER_SUPPLIER_REFUSE=Lieferantenbestellung abgelehnt
DemoDesc=Bei Dolibarr handelt es sich um ein kompaktes ERP/CRM-System, bestehend aus einzelnen Modulen. Da eine Demo aller Module kaum eine praxisnahe Anwendung darstellt, stehen Ihnen unterschiedliche Demo-Profile zur Verfügung.
SendNewPasswordDesc=Über dieses Formular können Sie sich ein neues Passwort zusenden lassen.
Die Änderungen an Ihrem Passwort werden erst wirksam, wenn Sie auf den im Mail enthaltenen Bestätigungslink klicken.
Überprüfen Sie den Posteingang Ihrer E-Mail-Anwendung.
EMailTextInterventionValidated=Eingriff %s freigegeben
@@ -163,8 +163,8 @@ EMailTextInvoiceValidated=Rechnung %s freigegeben
ImportedWithSet=Import Datensatz
DolibarrNotification=Automatische Benachrichtigung
-Notify_NOTIFY_VAL_ORDER=Kundenbestellung freigegeben
-Notify_NOTIFY_VAL_PROPAL=Angebot freigegeben
+Notify_ORDER_VALIDATE=Kundenbestellung freigegeben
+Notify_PROPAL_VALIDATE=Angebot freigegeben
PredefinedMailTest=Dies ist ein Test-Mail.\n Die beiden Zeilen sind durch eine Zeilenschaltung getrennt.
PredefinedMailTestHtml=Dies ist ein (HTML)-Test Mail (das Wort Test muss in Fettschrift erscheinen).
Die beiden Zeilen sollteb durch eine Zeilenschaltung getrennt sein.
CalculatedWeight=Errechnetes Gewicht
diff --git a/htdocs/langs/el_GR/other.lang b/htdocs/langs/el_GR/other.lang
index 3918032a84a..c88eaf91f09 100755
--- a/htdocs/langs/el_GR/other.lang
+++ b/htdocs/langs/el_GR/other.lang
@@ -25,15 +25,15 @@ BirthdayDate=Γενέθλια
DateToBirth=Ημερομ. γέννησης
BirthdayAlertOn=Ειδοποίηση γενεθλίων ενεργή
BirthdayAlertOff=Ειδοποίηση γενεθλίων ανενεργή
-Notify_NOTIFY_VAL_FICHINTER=Intervention validated
-Notify_NOTIFY_VAL_FAC=Το τιμολόγιο πελάτη επικυρώθηκε
-Notify_NOTIFY_APP_ORDER_SUPPLIER=Η παραγγελία προμηθευτή εγγρίθηκε
-Notify_NOTIFY_REF_ORDER_SUPPLIER=Η παραγγελία προμηθευτή απορρίφθηκε
-Notify_NOTIFY_VAL_ORDER=Η παραγγελία πελάτη επικυρώθηκε
-Notify_NOTIFY_VAL_PROPAL=Η εμπ. πρόταση πελάτη επικυρώθηκε
-Notify_NOTIFY_TRN_WITHDRAW=Transmission withdrawal
-Notify_NOTIFY_CRD_WITHDRAW=Credit withdrawal
-Notify_NOTIFY_EMT_WITHDRAW=Isue withdrawal
+Notify_FICHINTER_VALIDATE=Intervention validated
+Notify_BILL_VALIDATE=Το τιμολόγιο πελάτη επικυρώθηκε
+Notify_ORDER_SUPPLIER_APPROVE=Η παραγγελία προμηθευτή εγγρίθηκε
+Notify_ORDER_SUPPLIER_REFUSE=Η παραγγελία προμηθευτή απορρίφθηκε
+Notify_ORDER_VALIDATE=Η παραγγελία πελάτη επικυρώθηκε
+Notify_PROPAL_VALIDATE=Η εμπ. πρόταση πελάτη επικυρώθηκε
+Notify_WITHDRAW_TRANSMIT=Transmission withdrawal
+Notify_WITHDRAW_CREDIT=Credit withdrawal
+Notify_WITHDRAW_EMIT=Isue withdrawal
NbOfAttachedFiles=Πλήθος επισυναπτώμενων αρχείων/εγγράφων
TotalSizeOfAttachedFiles=Συνολικό μέγεθος επισυναπτώμενων αρχείων/εγγράφων
MaxSize=Μέγιστο μέγεθος
diff --git a/htdocs/langs/en_US/other.lang b/htdocs/langs/en_US/other.lang
index 6ef05e71d3c..fe4425d2ea3 100644
--- a/htdocs/langs/en_US/other.lang
+++ b/htdocs/langs/en_US/other.lang
@@ -26,15 +26,15 @@ BirthdayDate=Birthday
DateToBirth=Date to birth
BirthdayAlertOn= birthday alert active
BirthdayAlertOff= birthday alert inactive
-Notify_NOTIFY_VAL_FICHINTER=Intervention validated
-Notify_NOTIFY_VAL_FAC=Customer invoice validated
-Notify_NOTIFY_APP_ORDER_SUPPLIER=Supplier order approved
-Notify_NOTIFY_REF_ORDER_SUPPLIER=Supplier order refused
-Notify_NOTIFY_VAL_ORDER=Customer order validated
-Notify_NOTIFY_VAL_PROPAL=Customer proposal validated
-Notify_NOTIFY_TRN_WITHDRAW=Transmission withdrawal
-Notify_NOTIFY_CRD_WITHDRAW=Credit withdrawal
-Notify_NOTIFY_EMT_WITHDRAW=Isue withdrawal
+Notify_FICHINTER_VALIDATE=Intervention validated
+Notify_BILL_VALIDATE=Customer invoice validated
+Notify_ORDER_SUPPLIER_APPROVE=Supplier order approved
+Notify_ORDER_SUPPLIER_REFUSE=Supplier order refused
+Notify_ORDER_VALIDATE=Customer order validated
+Notify_PROPAL_VALIDATE=Customer proposal validated
+Notify_WITHDRAW_TRANSMIT=Transmission withdrawal
+Notify_WITHDRAW_CREDIT=Credit withdrawal
+Notify_WITHDRAW_EMIT=Isue withdrawal
NbOfAttachedFiles=Number of attached files/documents
TotalSizeOfAttachedFiles=Total size of attached files/documents
MaxSize=Maximum size
diff --git a/htdocs/langs/es_ES/other.lang b/htdocs/langs/es_ES/other.lang
index 780c0d8ffd0..de98996d7f6 100644
--- a/htdocs/langs/es_ES/other.lang
+++ b/htdocs/langs/es_ES/other.lang
@@ -26,15 +26,15 @@ BirthdayDate=Fecha aniversario
DateToBirth=Fecha de nacimiento
BirthdayAlertOn=alerta aniversario activada
BirthdayAlertOff=alerta aniversario desactivada
-Notify_NOTIFY_VAL_FICHINTER=Validación ficha intervención
-Notify_NOTIFY_VAL_FAC=Validación factura
-Notify_NOTIFY_APP_ORDER_SUPPLIER=Aprobación pedido a proveedor
-Notify_NOTIFY_REF_ORDER_SUPPLIER=Rechazo pedido a proveedor
-Notify_NOTIFY_VAL_ORDER=Validación pedido cliente
-Notify_NOTIFY_VAL_PROPAL=Validación presupuesto cliente
-Notify_NOTIFY_TRN_WITHDRAW=Transmisión domiciliación
-Notify_NOTIFY_CRD_WITHDRAW=Abono domiciliación
-Notify_NOTIFY_EMT_WITHDRAW=Emisión domiciliación
+Notify_FICHINTER_VALIDATE=Validación ficha intervención
+Notify_BILL_VALIDATE=Validación factura
+Notify_ORDER_SUPPLIER_APPROVE=Aprobación pedido a proveedor
+Notify_ORDER_SUPPLIER_REFUSE=Rechazo pedido a proveedor
+Notify_ORDER_VALIDATE=Validación pedido cliente
+Notify_PROPAL_VALIDATE=Validación presupuesto cliente
+Notify_WITHDRAW_TRANSMIT=Transmisión domiciliación
+Notify_WITHDRAW_CREDIT=Abono domiciliación
+Notify_WITHDRAW_EMIT=Emisión domiciliación
NbOfAttachedFiles=Número archivos/documentos adjuntos
TotalSizeOfAttachedFiles=Tamaño total de los archivos/documentos adjuntos
MaxSize=Tamaño máximo
diff --git a/htdocs/langs/fa_IR/other.lang b/htdocs/langs/fa_IR/other.lang
index d55514ac24b..b2ff1cbc493 100755
--- a/htdocs/langs/fa_IR/other.lang
+++ b/htdocs/langs/fa_IR/other.lang
@@ -35,10 +35,10 @@ BirthdayDate=عيد ميلاد
DateToBirth=تاريخ الميلاد
BirthdayAlertOn=عيد ميلاد النشطة في حالة تأهب
BirthdayAlertOff=عيد الميلاد فى حالة تأهب الخاملة
-Notify_NOTIFY_VAL_FICHINTER=تدخل المصادق
-Notify_NOTIFY_VAL_FAC=فاتورة مصادق
-Notify_NOTIFY_APP_ORDER_SUPPLIER=من أجل الموافقة على المورد
-Notify_NOTIFY_REF_ORDER_SUPPLIER=من أجل رفض الموردين
+Notify_FICHINTER_VALIDATE=تدخل المصادق
+Notify_BILL_VALIDATE=فاتورة مصادق
+Notify_ORDER_SUPPLIER_APPROVE=من أجل الموافقة على المورد
+Notify_ORDER_SUPPLIER_REFUSE=من أجل رفض الموردين
NbOfAttachedFiles=عدد الملفات المرفقة / وثائق
TotalSizeOfAttachedFiles=اجمالى حجم الملفات المرفقة / وثائق
MaxSize=الحجم الأقصى
@@ -187,8 +187,8 @@ NumberOfUnitsProposals=عدد من الوحدات على مقترحات بشأن
// START - Lines generated via autotranslator.php tool (2010-07-17 11:16:46).
// Reference language: en_US
-Notify_NOTIFY_VAL_ORDER=التحقق من صحة النظام العميل
-Notify_NOTIFY_VAL_PROPAL=التحقق من صحة اقتراح العملاء
+Notify_ORDER_VALIDATE=التحقق من صحة النظام العميل
+Notify_PROPAL_VALIDATE=التحقق من صحة اقتراح العملاء
PredefinedMailTest=هذا هو الاختبار الإلكتروني. تكون مفصولة \ nThe سطرين من قبل حرف إرجاع.
PredefinedMailTestHtml=هذا هو البريد الاختبار (الاختبار يجب أن تكون في كلمة جريئة).
وتفصل بين الخطين من قبل حرف إرجاع.
CalculatedWeight=يحسب الوزن
diff --git a/htdocs/langs/fi_FI/other.lang b/htdocs/langs/fi_FI/other.lang
index 47720a13d17..0de95dd58ef 100644
--- a/htdocs/langs/fi_FI/other.lang
+++ b/htdocs/langs/fi_FI/other.lang
@@ -33,8 +33,8 @@ Tools=Työkalut
Birthday=Syntymäpäivä
BirthdayDate=Syntymäpäivä
DateToBirth=Päiväys syntyvyyden
-Notify_NOTIFY_VAL_FICHINTER=Validate interventioelimen
-Notify_NOTIFY_VAL_FAC=Validate bill
+Notify_FICHINTER_VALIDATE=Validate interventioelimen
+Notify_BILL_VALIDATE=Validate bill
NbOfAttachedFiles=Numero liitettyjen tiedostojen / asiakirjat
TotalSizeOfAttachedFiles=Kokonaiskoosta liitettyjen tiedostojen / asiakirjat
MaxSize=Enimmäiskoko
@@ -162,8 +162,8 @@ NewExport=Uusia vientimahdollisuuksia
// Reference language: en_US
BirthdayAlertOn=syntymäpäivä hälytys aktiivinen
BirthdayAlertOff=syntymäpäivä varoituskynnysten inaktiivinen
-Notify_NOTIFY_APP_ORDER_SUPPLIER=Toimittaja jotta hyväksytty
-Notify_NOTIFY_REF_ORDER_SUPPLIER=Toimittaja jotta evätty
+Notify_ORDER_SUPPLIER_APPROVE=Toimittaja jotta hyväksytty
+Notify_ORDER_SUPPLIER_REFUSE=Toimittaja jotta evätty
DemoDesc=Dolibarr on kompakti ERP / CRM säveltänyt useita toiminnallisia moduuleja. A demo, joka sisältää kaikki moduulit eivät merkitse mitään, koska tämä ei koskaan tapahdu. Joten useita demo profiilit ovat saatavilla.
DemoCompanyServiceOnly=Hallinnoi freelance toimintaa myymällä palvelua vain
EMailTextInterventionValidated=Väliintulo %s validoitava
@@ -182,8 +182,8 @@ DemoFundation2=Jäsenten hallinta ja pankkitilille säätiön
// START - Lines generated via autotranslator.php tool (2010-07-17 11:26:22).
// Reference language: en_US
-Notify_NOTIFY_VAL_ORDER=Asiakas tilaa validoitu
-Notify_NOTIFY_VAL_PROPAL=Asiakas ehdotus validoidaan
+Notify_ORDER_VALIDATE=Asiakas tilaa validoitu
+Notify_PROPAL_VALIDATE=Asiakas ehdotus validoidaan
PredefinedMailTest=Tämä on testi postitse. \ NOsoitteen kaksi riviä välissä rivinvaihto.
PredefinedMailTestHtml=Tämä on testi postitse (sana testi on lihavoitu).
Kaksi riviä välissä rivinvaihto.
CalculatedWeight=Laskettu paino
diff --git a/htdocs/langs/fr_FR/other.lang b/htdocs/langs/fr_FR/other.lang
index 6944b52ed92..f56b8ea5df4 100644
--- a/htdocs/langs/fr_FR/other.lang
+++ b/htdocs/langs/fr_FR/other.lang
@@ -26,15 +26,15 @@ BirthdayDate=Date anniversaire
DateToBirth=Date de naissance
BirthdayAlertOn= alerte anniversaire active
BirthdayAlertOff= alerte anniversaire inactive
-Notify_NOTIFY_VAL_FICHINTER=Validation fiche intervention
-Notify_NOTIFY_VAL_FAC=Validation facture client
-Notify_NOTIFY_APP_ORDER_SUPPLIER=Approbation commande fournisseur
-Notify_NOTIFY_REF_ORDER_SUPPLIER=Refus commande fournisseur
-Notify_NOTIFY_VAL_ORDER=Validation commande client
-Notify_NOTIFY_VAL_PROPAL=Validation proposition commerciale client
-Notify_NOTIFY_TRN_WITHDRAW=Transmission prélèvement
-Notify_NOTIFY_CRD_WITHDRAW=Créditer prélèvement
-Notify_NOTIFY_EMT_WITHDRAW=Emission prélèvement
+Notify_FICHINTER_VALIDATE=Validation fiche intervention
+Notify_BILL_VALIDATE=Validation facture client
+Notify_ORDER_SUPPLIER_APPROVE=Approbation commande fournisseur
+Notify_ORDER_SUPPLIER_REFUSE=Refus commande fournisseur
+Notify_ORDER_VALIDATE=Validation commande client
+Notify_PROPAL_VALIDATE=Validation proposition commerciale client
+Notify_WITHDRAW_TRANSMIT=Transmission prélèvement
+Notify_WITHDRAW_CREDIT=Créditer prélèvement
+Notify_WITHDRAW_EMIT=Emission prélèvement
NbOfAttachedFiles=Nombre de fichiers/documents liés
TotalSizeOfAttachedFiles=Taille total fichiers/documents liés
MaxSize=Taille maximum
diff --git a/htdocs/langs/is_IS/other.lang b/htdocs/langs/is_IS/other.lang
index f1ad0400650..94569fb7bbe 100644
--- a/htdocs/langs/is_IS/other.lang
+++ b/htdocs/langs/is_IS/other.lang
@@ -33,12 +33,12 @@ BirthdayDate=Afmæli
DateToBirth=Dags til fæðingu
BirthdayAlertOn=afmæli viðvörun virk
BirthdayAlertOff=afmæli viðvörun óvirk
-Notify_NOTIFY_VAL_FICHINTER=Intervention staðfestar
-Notify_NOTIFY_VAL_FAC=Viðskiptavinur Reikningar staðfestar
-Notify_NOTIFY_APP_ORDER_SUPPLIER=Birgir röð samþykkt
-Notify_NOTIFY_REF_ORDER_SUPPLIER=Birgir þess neitaði
-Notify_NOTIFY_VAL_ORDER=Viðskiptavinur til setja í gildi
-Notify_NOTIFY_VAL_PROPAL=Viðskiptavinur tillögu staðfestar
+Notify_FICHINTER_VALIDATE=Intervention staðfestar
+Notify_BILL_VALIDATE=Viðskiptavinur Reikningar staðfestar
+Notify_ORDER_SUPPLIER_APPROVE=Birgir röð samþykkt
+Notify_ORDER_SUPPLIER_REFUSE=Birgir þess neitaði
+Notify_ORDER_VALIDATE=Viðskiptavinur til setja í gildi
+Notify_PROPAL_VALIDATE=Viðskiptavinur tillögu staðfestar
NbOfAttachedFiles=Fjöldi meðfylgjandi skrá / gögn
TotalSizeOfAttachedFiles=Heildarstærð meðfylgjandi skrá / gögn
MaxSize=Hámarks stærð
diff --git a/htdocs/langs/it_IT/other.lang b/htdocs/langs/it_IT/other.lang
index e0c6ce6e200..7570bc53c74 100644
--- a/htdocs/langs/it_IT/other.lang
+++ b/htdocs/langs/it_IT/other.lang
@@ -23,8 +23,8 @@ AddTrip =Aggiungi viaggio
Tools =Strumenti
Birthday =Compleanno
BirthdayDate =Data compleanno
-Notify_NOTIFY_VAL_FICHINTER =Convalida scheda intervento
-Notify_NOTIFY_VAL_FAC =Convalida fattura cliente
+Notify_FICHINTER_VALIDATE =Convalida scheda intervento
+Notify_BILL_VALIDATE =Convalida fattura cliente
NbOfAttachedFiles =Numero di file allegati / documenti
TotalSizeOfAttachedFiles =Dimensione totale dei file allegati / documenti
MaxSize =La dimensione massima è
@@ -162,8 +162,8 @@ MemberSubscriptionAddedInDolibarr=Abbonamento membro %s aggiunto in Dolibarr
// Reference language: en_US
BirthdayAlertOn=Attiva avviso compleanno
BirthdayAlertOff=Avviso compleanno inattivo
-Notify_NOTIFY_APP_ORDER_SUPPLIER=Fornitore fine approvato
-Notify_NOTIFY_REF_ORDER_SUPPLIER=Fornitore rifiutato per
+Notify_ORDER_SUPPLIER_APPROVE=Fornitore fine approvato
+Notify_ORDER_SUPPLIER_REFUSE=Fornitore rifiutato per
DemoDesc=Dolibarr è una applicazione ERP / CRM, composta da diversi moduli funzionali. Un demo che comprende tutti i moduli non è significativo riguardo al funzionamento. Così, diversi profili demo sono disponibili.
DemoCompanyServiceOnly=Gestire un servizio di free-lance di attività di solo vendita
SendNewPasswordDesc=Questo modulo consente di richiedere una nuova password. Sarà inviata al tuo indirizzo email.
Il cambiamento sarà effettivo solo dopo aver fatto clic sul link di conferma all'interno dell'email.
Controlla la tua casella e-mail.
@@ -176,8 +176,8 @@ DolibarrNotification=Notifica automatica
// START - Lines generated via autotranslator.php tool (2010-07-17 11:32:28).
// Reference language: en_US
-Notify_NOTIFY_VAL_ORDER=ordine del cliente convalidato
-Notify_NOTIFY_VAL_PROPAL=proposta del cliente convalidato
+Notify_ORDER_VALIDATE=ordine del cliente convalidato
+Notify_PROPAL_VALIDATE=proposta del cliente convalidato
PredefinedMailTest=Questa è una mail di prova. \ NIl due linee sono separate da un ritorno a capo.
PredefinedMailTestHtml=Questa è una mail di test (il test di parola deve essere in grassetto).
Le due linee sono separate da un ritorno a capo.
CalculatedWeight=Calcolo del peso
diff --git a/htdocs/langs/nb_NO/other.lang b/htdocs/langs/nb_NO/other.lang
index 7a3f3cdd040..53c3b4f40c8 100644
--- a/htdocs/langs/nb_NO/other.lang
+++ b/htdocs/langs/nb_NO/other.lang
@@ -24,8 +24,8 @@ Tools=Verktøy
Birthday=Fødselsdag
BirthdayDate=Fødselsdag
DateToBirth=Fødselsdag
-Notify_NOTIFY_VAL_FICHINTER=Godkjenn intervention
-Notify_NOTIFY_VAL_FAC=Godkjenn faktura
+Notify_FICHINTER_VALIDATE=Godkjenn intervention
+Notify_BILL_VALIDATE=Godkjenn faktura
NbOfAttachedFiles=Antall vedlagte filer/dokumenter
TotalSizeOfAttachedFiles=Total størrelse på vedlagte filer/dokumenter
MaxSize=Maksimal størrelse
@@ -148,10 +148,10 @@ NewExport=Ny eksport
// Reference language: en_US
BirthdayAlertOn=bursdag varsling aktive
BirthdayAlertOff=bursdag varsling inaktive
-Notify_NOTIFY_APP_ORDER_SUPPLIER=Leverandør bestill godkjent
-Notify_NOTIFY_REF_ORDER_SUPPLIER=Leverandør bestill nektet
-Notify_NOTIFY_VAL_ORDER=Kundeordre validert
-Notify_NOTIFY_VAL_PROPAL=Kunden forslaget validert
+Notify_ORDER_SUPPLIER_APPROVE=Leverandør bestill godkjent
+Notify_ORDER_SUPPLIER_REFUSE=Leverandør bestill nektet
+Notify_ORDER_VALIDATE=Kundeordre validert
+Notify_PROPAL_VALIDATE=Kunden forslaget validert
PredefinedMailTest=Dette er en test post. \ NDe to linjer er atskilt med en vognretur.
PredefinedMailTestHtml=Dette er en test mail (ordet testen må være i fet skrift).
De to linjene er skilt med en vognretur.
FeatureNotYetAvailableShort=Tilgjengelig i en neste versjon
diff --git a/htdocs/langs/nl_BE/other.lang b/htdocs/langs/nl_BE/other.lang
index 1af13376b56..aca96c56b85 100644
--- a/htdocs/langs/nl_BE/other.lang
+++ b/htdocs/langs/nl_BE/other.lang
@@ -23,8 +23,8 @@ Tools=Gereedschap
Birthday=Verjaardag
BirthdayDate=Datum verjaardag
DateToBirth=Geboortedatum
-Notify_NOTIFY_VAL_FICHINTER=Valideer interventie
-Notify_NOTIFY_VAL_FAC=Valideer factuur
+Notify_FICHINTER_VALIDATE=Valideer interventie
+Notify_BILL_VALIDATE=Valideer factuur
NbOfAttachedFiles=Aantal bijgevoegde bestanden / documenten
TotalSizeOfAttachedFiles=Totale omvang van de bijgevoegde bestanden / documenten
MaxSize=Maximale grootte
diff --git a/htdocs/langs/nl_NL/other.lang b/htdocs/langs/nl_NL/other.lang
index f59e3dc1cb0..40137af50e3 100644
--- a/htdocs/langs/nl_NL/other.lang
+++ b/htdocs/langs/nl_NL/other.lang
@@ -25,12 +25,12 @@ BirthdayDate=Verjaardagsdatum
DateToBirth=Geboortedatum
BirthdayAlertOn=Verjaardags waarschuwing actief
BirthdayAlertOff=verjaardags waarschuwing inactief
-Notify_NOTIFY_VAL_FICHINTER=Valideer interventie
-Notify_NOTIFY_VAL_FAC=Valideer factuur
-Notify_NOTIFY_APP_ORDER_SUPPLIER=Leverancier bestelling goedgekeurd
-Notify_NOTIFY_REF_ORDER_SUPPLIER=Leverancier bestelling geweigerd
-Notify_NOTIFY_VAL_ORDER=Verkoop order validatie
-Notify_NOTIFY_VAL_PROPAL=Validatie klant offerte
+Notify_FICHINTER_VALIDATE=Valideer interventie
+Notify_BILL_VALIDATE=Valideer factuur
+Notify_ORDER_SUPPLIER_APPROVE=Leverancier bestelling goedgekeurd
+Notify_ORDER_SUPPLIER_REFUSE=Leverancier bestelling geweigerd
+Notify_ORDER_VALIDATE=Verkoop order validatie
+Notify_PROPAL_VALIDATE=Validatie klant offerte
NbOfAttachedFiles=Aantal bijgevoegde bestanden/documenten
TotalSizeOfAttachedFiles=Totale omvang van de bijgevoegde bestanden/documenten
MaxSize=Maximale grootte
@@ -191,10 +191,10 @@ ExternalSites=Externe sites
// Reference language: en_US
BirthdayAlertOn=bursdag varsling aktive
BirthdayAlertOff=bursdag varsling inaktive
-Notify_NOTIFY_APP_ORDER_SUPPLIER=Leverandør bestill godkjent
-Notify_NOTIFY_REF_ORDER_SUPPLIER=Leverandør bestill nektet
-Notify_NOTIFY_VAL_ORDER=Kundeordre validert
-Notify_NOTIFY_VAL_PROPAL=Kunden forslaget validert
+Notify_ORDER_SUPPLIER_APPROVE=Leverandør bestill godkjent
+Notify_ORDER_SUPPLIER_REFUSE=Leverandør bestill nektet
+Notify_ORDER_VALIDATE=Kundeordre validert
+Notify_PROPAL_VALIDATE=Kunden forslaget validert
PredefinedMailTest=Dette er en test post. \ NDe to linjer er atskilt med en vognretur.
PredefinedMailTestHtml=Dette er en test mail (ordet testen må være i fet skrift).
De to linjene er skilt med en vognretur.
FeatureNotYetAvailableShort=Tilgjengelig i en neste versjon
@@ -239,8 +239,8 @@ CurrentInformationOnImage=Informasjon om gjeldende bilde
YouReceiveMailBecauseOfNotification=Du mottar denne meldingen fordi din e-post har blitt lagt til listen over mål for å bli informert om spesielle hendelser i %s programvare av %s.
YouReceiveMailBecauseOfNotification2=Denne hendelsen er følgende:
ExternalSites=Eksterne nettsteder
-Notify_NOTIFY_VAL_ORDER=Bestelling van de klant gevalideerd
-Notify_NOTIFY_VAL_PROPAL=Klant voorstel gevalideerd
+Notify_ORDER_VALIDATE=Bestelling van de klant gevalideerd
+Notify_PROPAL_VALIDATE=Klant voorstel gevalideerd
PredefinedMailTest=Dit is een test e-mail. \ NDe twee lijnen worden gescheiden door een harde return.
PredefinedMailTestHtml=Dit is een test e-mail (het woord test moet worden in het vet).
De twee lijnen worden gescheiden door een harde return.
CalculatedWeight=Berekend gewicht
diff --git a/htdocs/langs/pl_PL/other.lang b/htdocs/langs/pl_PL/other.lang
index 43ab256b57c..e65744a50a5 100644
--- a/htdocs/langs/pl_PL/other.lang
+++ b/htdocs/langs/pl_PL/other.lang
@@ -35,8 +35,8 @@ Tools=Narzędzia
Birthday=Urodziny
BirthdayDate=Urodziny
DateToBirth=Data urodzenia
-Notify_NOTIFY_VAL_FICHINTER=Validate interwencji
-Notify_NOTIFY_VAL_FAC=Sprawdź rachunki
+Notify_FICHINTER_VALIDATE=Validate interwencji
+Notify_BILL_VALIDATE=Sprawdź rachunki
NbOfAttachedFiles=Liczba załączonych plików / dokumentów
TotalSizeOfAttachedFiles=Całkowita wielkość załączonych plików / dokumentów
MaxSize=Maksymalny rozmiar
@@ -164,8 +164,8 @@ NewExport=Nowy eksport
// Reference language: en_US
BirthdayAlertOn=urodziny wpisu aktywnych
BirthdayAlertOff=urodziny wpisu nieaktywne
-Notify_NOTIFY_APP_ORDER_SUPPLIER=Dostawca celu zatwierdzone
-Notify_NOTIFY_REF_ORDER_SUPPLIER=Dostawca odmówił celu
+Notify_ORDER_SUPPLIER_APPROVE=Dostawca celu zatwierdzone
+Notify_ORDER_SUPPLIER_REFUSE=Dostawca odmówił celu
DemoDesc=Dolibarr jest kompaktowym ERP / CRM złożona z kilku modułów funkcjonalnych. A demo, które zawiera wszystkie moduły nie oznacza nic, ponieważ nie występuje. Tak więc, kilka profili są dostępne demo.
DemoCompanyServiceOnly=Zarządzanie wolny działalności sprzedaży usług tylko
SendNewPasswordDesc=Ta forma pozwala na złożenie wniosku o nowe hasło. Będzie wyślij swój adres e-mail.
Zmiana będzie skuteczne dopiero po kliknięciu na link potwierdzający wewnątrz tej wiadomości.
Sprawdź pocztę czytnik oprogramowania.
@@ -180,10 +180,10 @@ DolibarrNotification=Automatyczne powiadomienia
// Reference language: en_US
BirthdayAlertOn=bursdag varsling aktive
BirthdayAlertOff=bursdag varsling inaktive
-Notify_NOTIFY_APP_ORDER_SUPPLIER=Leverandør bestill godkjent
-Notify_NOTIFY_REF_ORDER_SUPPLIER=Leverandør bestill nektet
-Notify_NOTIFY_VAL_ORDER=Kundeordre validert
-Notify_NOTIFY_VAL_PROPAL=Kunden forslaget validert
+Notify_ORDER_SUPPLIER_APPROVE=Leverandør bestill godkjent
+Notify_ORDER_SUPPLIER_REFUSE=Leverandør bestill nektet
+Notify_ORDER_VALIDATE=Kundeordre validert
+Notify_PROPAL_VALIDATE=Kunden forslaget validert
PredefinedMailTest=Dette er en test post. \ NDe to linjer er atskilt med en vognretur.
PredefinedMailTestHtml=Dette er en test mail (ordet testen må være i fet skrift).
De to linjene er skilt med en vognretur.
FeatureNotYetAvailableShort=Tilgjengelig i en neste versjon
@@ -228,8 +228,8 @@ CurrentInformationOnImage=Informasjon om gjeldende bilde
YouReceiveMailBecauseOfNotification=Du mottar denne meldingen fordi din e-post har blitt lagt til listen over mål for å bli informert om spesielle hendelser i %s programvare av %s.
YouReceiveMailBecauseOfNotification2=Denne hendelsen er følgende:
ExternalSites=Eksterne nettsteder
-Notify_NOTIFY_VAL_ORDER=Bestelling van de klant gevalideerd
-Notify_NOTIFY_VAL_PROPAL=Klant voorstel gevalideerd
+Notify_ORDER_VALIDATE=Bestelling van de klant gevalideerd
+Notify_PROPAL_VALIDATE=Klant voorstel gevalideerd
PredefinedMailTest=Dit is een test e-mail. \ NDe twee lijnen worden gescheiden door een harde return.
PredefinedMailTestHtml=Dit is een test e-mail (het woord test moet worden in het vet).
De twee lijnen worden gescheiden door een harde return.
CalculatedWeight=Berekend gewicht
@@ -259,8 +259,8 @@ CalculatedWeight=Berekend gewicht
CalculatedVolume=Berekende volume
YouReceiveMailBecauseOfNotification=U ontvangt dit bericht omdat uw e-mail is toegevoegd aan de lijst van doelstellingen te worden geïnformeerd over bepaalde gebeurtenissen in de software van sssss sssss.
YouReceiveMailBecauseOfNotification2=Dit evenement is de volgende:
-Notify_NOTIFY_VAL_ORDER=Aby Klient zatwierdzone
-Notify_NOTIFY_VAL_PROPAL=wniosek Klienta zatwierdzone
+Notify_ORDER_VALIDATE=Aby Klient zatwierdzone
+Notify_PROPAL_VALIDATE=wniosek Klienta zatwierdzone
PredefinedMailTest=To jest test mail. Czeka na zatwierdzenie nowego dwie linie oddzielone są znakiem powrotu karetki.
PredefinedMailTestHtml=To jest mail do badań (test słowa muszą być pogrubione).
Dwie linie oddzielone są znakiem powrotu karetki.
CalculatedWeight=Oblicza masy
diff --git a/htdocs/langs/pt_BR/other.lang b/htdocs/langs/pt_BR/other.lang
index 6ef736be06f..e3e4579298b 100644
--- a/htdocs/langs/pt_BR/other.lang
+++ b/htdocs/langs/pt_BR/other.lang
@@ -26,8 +26,8 @@ BirthdayDate=Data Aniversário
DateToBirth=Data de Nascimento
BirthdayAlertOn=Alerta de aniversário ativo
BirthdayAlertOff=Alerta de aniversário desativado
-Notify_NOTIFY_VAL_FICHINTER=Validação Ficha Intervenção
-Notify_NOTIFY_VAL_FAC=Validação Fatura
+Notify_FICHINTER_VALIDATE=Validação Ficha Intervenção
+Notify_BILL_VALIDATE=Validação Fatura
NbOfAttachedFiles=Número Arquivos/Documentos Anexos
TotalSizeOfAttachedFiles=Tamanho Total dos Arquivos/Documentos Anexos
MaxSize=Tamanho Máximo
diff --git a/htdocs/langs/pt_PT/other.lang b/htdocs/langs/pt_PT/other.lang
index bfbc0bb3354..42e54ad942f 100644
--- a/htdocs/langs/pt_PT/other.lang
+++ b/htdocs/langs/pt_PT/other.lang
@@ -24,8 +24,8 @@ Tools=Utilidades
Birthday=Aniversario
BirthdayDate=Data Aniversario
DateToBirth=Data de Nascimento
-Notify_NOTIFY_VAL_FICHINTER=Validação Ficha Intervenção
-Notify_NOTIFY_VAL_FAC=Validação factura
+Notify_FICHINTER_VALIDATE=Validação Ficha Intervenção
+Notify_BILL_VALIDATE=Validação factura
NbOfAttachedFiles=Número Ficheiros/Documentos anexos
TotalSizeOfAttachedFiles=Tamanho Total dos Ficheiros/Documentos anexos
MaxSize=Tamanho Máximo
@@ -159,8 +159,8 @@ NewExport=Nova Exportação
// Reference language: en_US
BirthdayAlertOn=Alerta de aniversário activas
BirthdayAlertOff=aniversário alerta inativo
-Notify_NOTIFY_APP_ORDER_SUPPLIER=Fornecedor fim aprovado
-Notify_NOTIFY_REF_ORDER_SUPPLIER=Fornecedor fim recusada
+Notify_ORDER_SUPPLIER_APPROVE=Fornecedor fim aprovado
+Notify_ORDER_SUPPLIER_REFUSE=Fornecedor fim recusada
EMailTextInterventionValidated=Intervenção %s validados
EMailTextInvoiceValidated=Factura %s validados
ImportedWithSet=Importação conjunto de dados
@@ -172,10 +172,10 @@ DolibarrNotification=Notificação automática
// Reference language: en_US
BirthdayAlertOn=bursdag varsling aktive
BirthdayAlertOff=bursdag varsling inaktive
-Notify_NOTIFY_APP_ORDER_SUPPLIER=Leverandør bestill godkjent
-Notify_NOTIFY_REF_ORDER_SUPPLIER=Leverandør bestill nektet
-Notify_NOTIFY_VAL_ORDER=Kundeordre validert
-Notify_NOTIFY_VAL_PROPAL=Kunden forslaget validert
+Notify_ORDER_SUPPLIER_APPROVE=Leverandør bestill godkjent
+Notify_ORDER_SUPPLIER_REFUSE=Leverandør bestill nektet
+Notify_ORDER_VALIDATE=Kundeordre validert
+Notify_PROPAL_VALIDATE=Kunden forslaget validert
PredefinedMailTest=Dette er en test post. \ NDe to linjer er atskilt med en vognretur.
PredefinedMailTestHtml=Dette er en test mail (ordet testen må være i fet skrift).
De to linjene er skilt med en vognretur.
FeatureNotYetAvailableShort=Tilgjengelig i en neste versjon
@@ -220,8 +220,8 @@ CurrentInformationOnImage=Informasjon om gjeldende bilde
YouReceiveMailBecauseOfNotification=Du mottar denne meldingen fordi din e-post har blitt lagt til listen over mål for å bli informert om spesielle hendelser i %s programvare av %s.
YouReceiveMailBecauseOfNotification2=Denne hendelsen er følgende:
ExternalSites=Eksterne nettsteder
-Notify_NOTIFY_VAL_ORDER=Bestelling van de klant gevalideerd
-Notify_NOTIFY_VAL_PROPAL=Klant voorstel gevalideerd
+Notify_ORDER_VALIDATE=Bestelling van de klant gevalideerd
+Notify_PROPAL_VALIDATE=Klant voorstel gevalideerd
PredefinedMailTest=Dit is een test e-mail. \ NDe twee lijnen worden gescheiden door een harde return.
PredefinedMailTestHtml=Dit is een test e-mail (het woord test moet worden in het vet).
De twee lijnen worden gescheiden door een harde return.
CalculatedWeight=Berekend gewicht
@@ -251,8 +251,8 @@ CalculatedWeight=Berekend gewicht
CalculatedVolume=Berekende volume
YouReceiveMailBecauseOfNotification=U ontvangt dit bericht omdat uw e-mail is toegevoegd aan de lijst van doelstellingen te worden geïnformeerd over bepaalde gebeurtenissen in de software van sssss sssss.
YouReceiveMailBecauseOfNotification2=Dit evenement is de volgende:
-Notify_NOTIFY_VAL_ORDER=Aby Klient zatwierdzone
-Notify_NOTIFY_VAL_PROPAL=wniosek Klienta zatwierdzone
+Notify_ORDER_VALIDATE=Aby Klient zatwierdzone
+Notify_PROPAL_VALIDATE=wniosek Klienta zatwierdzone
PredefinedMailTest=To jest test mail. Czeka na zatwierdzenie nowego dwie linie oddzielone są znakiem powrotu karetki.
PredefinedMailTestHtml=To jest mail do badań (test słowa muszą być pogrubione).
Dwie linie oddzielone są znakiem powrotu karetki.
CalculatedWeight=Oblicza masy
@@ -279,8 +279,8 @@ CurrentInformationOnImage=Informacje na temat bieżącego obrazu
YouReceiveMailBecauseOfNotification=Pojawieniu się tego komunikatu, ponieważ e-mail został dodany do listy celów do informacji o wydarzeniach w szczególności z sssss sssss oprogramowania.
YouReceiveMailBecauseOfNotification2=To wydarzenie jest następujące:
ExternalSites=tereny zewnętrzne
-Notify_NOTIFY_VAL_ORDER=ordem do cliente validado
-Notify_NOTIFY_VAL_PROPAL=proposta do cliente validado
+Notify_ORDER_VALIDATE=ordem do cliente validado
+Notify_PROPAL_VALIDATE=proposta do cliente validado
PredefinedMailTest=Este é um mail de teste. \ NO duas linhas são separadas por um retorno de carro.
PredefinedMailTestHtml=Este é um mail de teste (o teste da Palavra deve ser em negrito).
As duas linhas são separadas por um retorno de carro.
CalculatedWeight=peso calculado
diff --git a/htdocs/langs/ro_RO/other.lang b/htdocs/langs/ro_RO/other.lang
index c5855bc9832..e5afbd078ee 100644
--- a/htdocs/langs/ro_RO/other.lang
+++ b/htdocs/langs/ro_RO/other.lang
@@ -33,8 +33,8 @@ Tools=Instrumente
Birthday=Zi de naştere
BirthdayDate=Zi de naştere
DateToBirth=Data de naştere
-Notify_NOTIFY_VAL_FICHINTER=Validate intervenţie
-Notify_NOTIFY_VAL_FAC=Validate factura
+Notify_FICHINTER_VALIDATE=Validate intervenţie
+Notify_BILL_VALIDATE=Validate factura
NbOfAttachedFiles=Numărul de ataşat fişiere / documente
TotalSizeOfAttachedFiles=Total marimea ataşat fişiere / documente
MaxSize=Mărimea maximă a
@@ -162,8 +162,8 @@ NewExport=New export
// Reference language: en_US
BirthdayAlertOn=ziua de nastere de alertă activă
BirthdayAlertOff=ziua de nastere de alertă inactiv
-Notify_NOTIFY_APP_ORDER_SUPPLIER=Furnizor pentru a aprobat
-Notify_NOTIFY_REF_ORDER_SUPPLIER=Furnizor pentru a refuzat
+Notify_ORDER_SUPPLIER_APPROVE=Furnizor pentru a aprobat
+Notify_ORDER_SUPPLIER_REFUSE=Furnizor pentru a refuzat
DemoDesc=Dolibarr este un compact ERP / CRM compus din mai multe module funcţionale. Un demo care include toate modulele nu înseamnă nimic, deoarece aceasta nu se produce. Deci, mai multe demo-profile sunt disponibile.
DemoCompanyServiceOnly=Gestionaţi o independenţi activitate vânzarea de servicii numai
SendNewPasswordDesc=Acest formular vă permite să solicitaţi o parolă nouă. Se va trimite la adresa de e-mail.
Modificarea va fi în vigoare doar după ce fac clic pe link-ul de confirmare în interiorul acestui email.
Verificaţi-vă de e-mail reader software.
@@ -176,8 +176,8 @@ DolibarrNotification=Automat de notificare
// START - Lines generated via autotranslator.php tool (2010-07-17 11:36:47).
// Reference language: en_US
-Notify_NOTIFY_VAL_ORDER=Pentru clienţilor validate
-Notify_NOTIFY_VAL_PROPAL=Propunerea clienţilor validate
+Notify_ORDER_VALIDATE=Pentru clienţilor validate
+Notify_PROPAL_VALIDATE=Propunerea clienţilor validate
PredefinedMailTest=Acesta este un e-mail de test. \ NMesajul două linii sunt separate printr-un retur de car.
PredefinedMailTestHtml=Acesta este un e-mail de testare (test de cuvânt trebuie să fie în aldine).
Cele două linii sunt separate printr-un retur de car.
CalculatedWeight=Calculat în greutate
@@ -211,10 +211,10 @@ ExternalSites=Site-uri externe
// Reference language: en_US
BirthdayAlertOn=bursdag varsling aktive
BirthdayAlertOff=bursdag varsling inaktive
-Notify_NOTIFY_APP_ORDER_SUPPLIER=Leverandør bestill godkjent
-Notify_NOTIFY_REF_ORDER_SUPPLIER=Leverandør bestill nektet
-Notify_NOTIFY_VAL_ORDER=Kundeordre validert
-Notify_NOTIFY_VAL_PROPAL=Kunden forslaget validert
+Notify_ORDER_SUPPLIER_APPROVE=Leverandør bestill godkjent
+Notify_ORDER_SUPPLIER_REFUSE=Leverandør bestill nektet
+Notify_ORDER_VALIDATE=Kundeordre validert
+Notify_PROPAL_VALIDATE=Kunden forslaget validert
PredefinedMailTest=Dette er en test post. \ NDe to linjer er atskilt med en vognretur.
PredefinedMailTestHtml=Dette er en test mail (ordet testen må være i fet skrift).
De to linjene er skilt med en vognretur.
FeatureNotYetAvailableShort=Tilgjengelig i en neste versjon
@@ -259,8 +259,8 @@ CurrentInformationOnImage=Informasjon om gjeldende bilde
YouReceiveMailBecauseOfNotification=Du mottar denne meldingen fordi din e-post har blitt lagt til listen over mål for å bli informert om spesielle hendelser i %s programvare av %s.
YouReceiveMailBecauseOfNotification2=Denne hendelsen er følgende:
ExternalSites=Eksterne nettsteder
-Notify_NOTIFY_VAL_ORDER=Bestelling van de klant gevalideerd
-Notify_NOTIFY_VAL_PROPAL=Klant voorstel gevalideerd
+Notify_ORDER_VALIDATE=Bestelling van de klant gevalideerd
+Notify_PROPAL_VALIDATE=Klant voorstel gevalideerd
PredefinedMailTest=Dit is een test e-mail. \ NDe twee lijnen worden gescheiden door een harde return.
PredefinedMailTestHtml=Dit is een test e-mail (het woord test moet worden in het vet).
De twee lijnen worden gescheiden door een harde return.
CalculatedWeight=Berekend gewicht
@@ -290,8 +290,8 @@ CalculatedWeight=Berekend gewicht
CalculatedVolume=Berekende volume
YouReceiveMailBecauseOfNotification=U ontvangt dit bericht omdat uw e-mail is toegevoegd aan de lijst van doelstellingen te worden geïnformeerd over bepaalde gebeurtenissen in de software van sssss sssss.
YouReceiveMailBecauseOfNotification2=Dit evenement is de volgende:
-Notify_NOTIFY_VAL_ORDER=Aby Klient zatwierdzone
-Notify_NOTIFY_VAL_PROPAL=wniosek Klienta zatwierdzone
+Notify_ORDER_VALIDATE=Aby Klient zatwierdzone
+Notify_PROPAL_VALIDATE=wniosek Klienta zatwierdzone
PredefinedMailTest=To jest test mail. Czeka na zatwierdzenie nowego dwie linie oddzielone są znakiem powrotu karetki.
PredefinedMailTestHtml=To jest mail do badań (test słowa muszą być pogrubione).
Dwie linie oddzielone są znakiem powrotu karetki.
CalculatedWeight=Oblicza masy
@@ -318,8 +318,8 @@ CurrentInformationOnImage=Informacje na temat bieżącego obrazu
YouReceiveMailBecauseOfNotification=Pojawieniu się tego komunikatu, ponieważ e-mail został dodany do listy celów do informacji o wydarzeniach w szczególności z sssss sssss oprogramowania.
YouReceiveMailBecauseOfNotification2=To wydarzenie jest następujące:
ExternalSites=tereny zewnętrzne
-Notify_NOTIFY_VAL_ORDER=ordem do cliente validado
-Notify_NOTIFY_VAL_PROPAL=proposta do cliente validado
+Notify_ORDER_VALIDATE=ordem do cliente validado
+Notify_PROPAL_VALIDATE=proposta do cliente validado
PredefinedMailTest=Este é um mail de teste. \ NO duas linhas são separadas por um retorno de carro.
PredefinedMailTestHtml=Este é um mail de teste (o teste da Palavra deve ser em negrito).
As duas linhas são separadas por um retorno de carro.
CalculatedWeight=peso calculado
diff --git a/htdocs/langs/ru_RU/other.lang b/htdocs/langs/ru_RU/other.lang
index 7e447620566..e9c5ab21222 100644
--- a/htdocs/langs/ru_RU/other.lang
+++ b/htdocs/langs/ru_RU/other.lang
@@ -33,8 +33,8 @@ Tools=Инструменты
Birthday=День рождения
BirthdayDate=День рождения
DateToBirth=Дата рождения
-Notify_NOTIFY_VAL_FICHINTER=Проверка вмешательства
-Notify_NOTIFY_VAL_FAC=Проверка векселя
+Notify_FICHINTER_VALIDATE=Проверка вмешательства
+Notify_BILL_VALIDATE=Проверка векселя
NbOfAttachedFiles=Количество прикрепленных файлов / документов
TotalSizeOfAttachedFiles=Общий размер присоединенных файлов / документы
MaxSize=Максимальный размер
@@ -162,8 +162,8 @@ NewExport=Новый экспорт
// Reference language: en_US
BirthdayAlertOn=рождения активного оповещения
BirthdayAlertOff=рождения оповещения неактивные
-Notify_NOTIFY_APP_ORDER_SUPPLIER=Поставщик утвердил порядок
-Notify_NOTIFY_REF_ORDER_SUPPLIER=Поставщик порядке отказалась
+Notify_ORDER_SUPPLIER_APPROVE=Поставщик утвердил порядок
+Notify_ORDER_SUPPLIER_REFUSE=Поставщик порядке отказалась
DemoDesc=Dolibarr является компактным ERP / CRM составе нескольких функциональных модулей. В демо, что включает в себя все модули, не означает ничего, как этого никогда не происходит. Так, несколько демо-профилей доступны.
DemoCompanyServiceOnly=Управление внештатным деятельности службы только в продаже
SendNewPasswordDesc=Эта форма позволяет запросить новый пароль. Он будет отправить на ваш адрес электронной почты.
Изменения вступят в силу только после нажатия на ссылку в подтверждение этого сообщения.
Проверьте ваш электронный читатель программного обеспечения.
@@ -178,10 +178,10 @@ DolibarrNotification=Автоматические уведомления
// Reference language: en_US
BirthdayAlertOn=bursdag varsling aktive
BirthdayAlertOff=bursdag varsling inaktive
-Notify_NOTIFY_APP_ORDER_SUPPLIER=Leverandør bestill godkjent
-Notify_NOTIFY_REF_ORDER_SUPPLIER=Leverandør bestill nektet
-Notify_NOTIFY_VAL_ORDER=Kundeordre validert
-Notify_NOTIFY_VAL_PROPAL=Kunden forslaget validert
+Notify_ORDER_SUPPLIER_APPROVE=Leverandør bestill godkjent
+Notify_ORDER_SUPPLIER_REFUSE=Leverandør bestill nektet
+Notify_ORDER_VALIDATE=Kundeordre validert
+Notify_PROPAL_VALIDATE=Kunden forslaget validert
PredefinedMailTest=Dette er en test post. \ NDe to linjer er atskilt med en vognretur.
PredefinedMailTestHtml=Dette er en test mail (ordet testen må være i fet skrift).
De to linjene er skilt med en vognretur.
FeatureNotYetAvailableShort=Tilgjengelig i en neste versjon
@@ -226,8 +226,8 @@ CurrentInformationOnImage=Informasjon om gjeldende bilde
YouReceiveMailBecauseOfNotification=Du mottar denne meldingen fordi din e-post har blitt lagt til listen over mål for å bli informert om spesielle hendelser i %s programvare av %s.
YouReceiveMailBecauseOfNotification2=Denne hendelsen er følgende:
ExternalSites=Eksterne nettsteder
-Notify_NOTIFY_VAL_ORDER=Bestelling van de klant gevalideerd
-Notify_NOTIFY_VAL_PROPAL=Klant voorstel gevalideerd
+Notify_ORDER_VALIDATE=Bestelling van de klant gevalideerd
+Notify_PROPAL_VALIDATE=Klant voorstel gevalideerd
PredefinedMailTest=Dit is een test e-mail. \ NDe twee lijnen worden gescheiden door een harde return.
PredefinedMailTestHtml=Dit is een test e-mail (het woord test moet worden in het vet).
De twee lijnen worden gescheiden door een harde return.
CalculatedWeight=Berekend gewicht
@@ -257,8 +257,8 @@ CalculatedWeight=Berekend gewicht
CalculatedVolume=Berekende volume
YouReceiveMailBecauseOfNotification=U ontvangt dit bericht omdat uw e-mail is toegevoegd aan de lijst van doelstellingen te worden geïnformeerd over bepaalde gebeurtenissen in de software van sssss sssss.
YouReceiveMailBecauseOfNotification2=Dit evenement is de volgende:
-Notify_NOTIFY_VAL_ORDER=Aby Klient zatwierdzone
-Notify_NOTIFY_VAL_PROPAL=wniosek Klienta zatwierdzone
+Notify_ORDER_VALIDATE=Aby Klient zatwierdzone
+Notify_PROPAL_VALIDATE=wniosek Klienta zatwierdzone
PredefinedMailTest=To jest test mail. Czeka na zatwierdzenie nowego dwie linie oddzielone są znakiem powrotu karetki.
PredefinedMailTestHtml=To jest mail do badań (test słowa muszą być pogrubione).
Dwie linie oddzielone są znakiem powrotu karetki.
CalculatedWeight=Oblicza masy
@@ -285,8 +285,8 @@ CurrentInformationOnImage=Informacje na temat bieżącego obrazu
YouReceiveMailBecauseOfNotification=Pojawieniu się tego komunikatu, ponieważ e-mail został dodany do listy celów do informacji o wydarzeniach w szczególności z sssss sssss oprogramowania.
YouReceiveMailBecauseOfNotification2=To wydarzenie jest następujące:
ExternalSites=tereny zewnętrzne
-Notify_NOTIFY_VAL_ORDER=ordem do cliente validado
-Notify_NOTIFY_VAL_PROPAL=proposta do cliente validado
+Notify_ORDER_VALIDATE=ordem do cliente validado
+Notify_PROPAL_VALIDATE=proposta do cliente validado
PredefinedMailTest=Este é um mail de teste. \ NO duas linhas são separadas por um retorno de carro.
PredefinedMailTestHtml=Este é um mail de teste (o teste da Palavra deve ser em negrito).
As duas linhas são separadas por um retorno de carro.
CalculatedWeight=peso calculado
@@ -312,8 +312,8 @@ CurrentInformationOnImage=Informações sobre a imagem atual
YouReceiveMailBecauseOfNotification=Você receberá esta mensagem porque seu e-mail foi adicionado à lista de alvos a ser informado dos acontecimentos em particular do software %s %s.
YouReceiveMailBecauseOfNotification2=Este evento é o seguinte:
ExternalSites=Sites externos
-Notify_NOTIFY_VAL_ORDER=Клиент для проверки
-Notify_NOTIFY_VAL_PROPAL=Клиент предложение проверки
+Notify_ORDER_VALIDATE=Клиент для проверки
+Notify_PROPAL_VALIDATE=Клиент предложение проверки
PredefinedMailTest=Это тест почты. \ NЭтот две строки, разделенные символом возврата каретки.
PredefinedMailTestHtml=Это тест почты (слово "испытание должно быть жирным шрифтом).
2 линии разделяются символом возврата каретки.
CalculatedWeight=Расчетный вес
diff --git a/htdocs/langs/sl_SI/other.lang b/htdocs/langs/sl_SI/other.lang
index 8e2b0c22833..8862bd93a06 100755
--- a/htdocs/langs/sl_SI/other.lang
+++ b/htdocs/langs/sl_SI/other.lang
@@ -26,15 +26,15 @@ BirthdayDate=Rojstni dan
DateToBirth=Datum rojstva
BirthdayAlertOn = Vklopljeno opozorilo na rojstni dan
BirthdayAlertOff = Izklopljeno opozorilo na rojstni dan
-Notify_NOTIFY_VAL_FICHINTER=Potrjena intervencija
-Notify_NOTIFY_VAL_FAC=Potrjen račun
-Notify_NOTIFY_APP_ORDER_SUPPLIER=Odobreno naročilo pri dobavitelju
-Notify_NOTIFY_REF_ORDER_SUPPLIER=Zavrnjeno naročilo pri dobavitelju
-Notify_NOTIFY_VAL_ORDER=Potrjeno naročilo kupca
-Notify_NOTIFY_VAL_PROPAL=Potrjena ponudba kupcu
-Notify_NOTIFY_TRN_WITHDRAW=Nakazilo prenosa
-Notify_NOTIFY_CRD_WITHDRAW=Nakazilo kredita
-Notify_NOTIFY_EMT_WITHDRAW=Isue withdrawal
+Notify_FICHINTER_VALIDATE=Potrjena intervencija
+Notify_BILL_VALIDATE=Potrjen račun
+Notify_ORDER_SUPPLIER_APPROVE=Odobreno naročilo pri dobavitelju
+Notify_ORDER_SUPPLIER_REFUSE=Zavrnjeno naročilo pri dobavitelju
+Notify_ORDER_VALIDATE=Potrjeno naročilo kupca
+Notify_PROPAL_VALIDATE=Potrjena ponudba kupcu
+Notify_WITHDRAW_TRANSMIT=Nakazilo prenosa
+Notify_WITHDRAW_CREDIT=Nakazilo kredita
+Notify_WITHDRAW_EMIT=Isue withdrawal
NbOfAttachedFiles=Število pripetih datotek/dokumentov
TotalSizeOfAttachedFiles=Skupna velikost pripetih datotek/dokumentov
MaxSize=Največja velikost
diff --git a/htdocs/langs/sv_SE/other.lang b/htdocs/langs/sv_SE/other.lang
index 1e08051c97d..b13768796f6 100755
--- a/htdocs/langs/sv_SE/other.lang
+++ b/htdocs/langs/sv_SE/other.lang
@@ -33,12 +33,12 @@ BirthdayDate=Födelsedag
DateToBirth=Datum för födelse
BirthdayAlertOn=födelsedag alert aktiva
BirthdayAlertOff=födelsedag alert inaktiv
-Notify_NOTIFY_VAL_FICHINTER=Intervention validerade
-Notify_NOTIFY_VAL_FAC=Kundfaktura validerade
-Notify_NOTIFY_APP_ORDER_SUPPLIER=Leverantör för godkänd
-Notify_NOTIFY_REF_ORDER_SUPPLIER=Leverantör för vägrat
-Notify_NOTIFY_VAL_ORDER=Kundorder validerade
-Notify_NOTIFY_VAL_PROPAL=Kunden förslag validerade
+Notify_FICHINTER_VALIDATE=Intervention validerade
+Notify_BILL_VALIDATE=Kundfaktura validerade
+Notify_ORDER_SUPPLIER_APPROVE=Leverantör för godkänd
+Notify_ORDER_SUPPLIER_REFUSE=Leverantör för vägrat
+Notify_ORDER_VALIDATE=Kundorder validerade
+Notify_PROPAL_VALIDATE=Kunden förslag validerade
NbOfAttachedFiles=Antal bifogade filer / dokument
TotalSizeOfAttachedFiles=Total storlek på bifogade filer / dokument
MaxSize=Maximal storlek
diff --git a/htdocs/langs/tr_TR/other.lang b/htdocs/langs/tr_TR/other.lang
index 40da7ee5ba5..17dd0cc7922 100644
--- a/htdocs/langs/tr_TR/other.lang
+++ b/htdocs/langs/tr_TR/other.lang
@@ -34,10 +34,10 @@ BirthdayDate=Doğum günü
DateToBirth=Doğum için Tarih
BirthdayAlertOn=doğum bildirim etkin
BirthdayAlertOff=doğum bildirim etkin
-Notify_NOTIFY_VAL_FICHINTER=Müdahale validated
-Notify_NOTIFY_VAL_FAC=Fatura validated
-Notify_NOTIFY_APP_ORDER_SUPPLIER=Tedarikçi sipariş onaylanmış
-Notify_NOTIFY_REF_ORDER_SUPPLIER=Tedarikçi sipariş reddetti
+Notify_FICHINTER_VALIDATE=Müdahale validated
+Notify_BILL_VALIDATE=Fatura validated
+Notify_ORDER_SUPPLIER_APPROVE=Tedarikçi sipariş onaylanmış
+Notify_ORDER_SUPPLIER_REFUSE=Tedarikçi sipariş reddetti
NbOfAttachedFiles=Numarası ekli dosyaları / belgeleri
TotalSizeOfAttachedFiles=Ekli dosyaların toplam boyutu / belgeleri
MaxSize=Maksimum boyut
@@ -174,10 +174,10 @@ NewExport=Ihracat
// Reference language: en_US
BirthdayAlertOn=bursdag varsling aktive
BirthdayAlertOff=bursdag varsling inaktive
-Notify_NOTIFY_APP_ORDER_SUPPLIER=Leverandør bestill godkjent
-Notify_NOTIFY_REF_ORDER_SUPPLIER=Leverandør bestill nektet
-Notify_NOTIFY_VAL_ORDER=Kundeordre validert
-Notify_NOTIFY_VAL_PROPAL=Kunden forslaget validert
+Notify_ORDER_SUPPLIER_APPROVE=Leverandør bestill godkjent
+Notify_ORDER_SUPPLIER_REFUSE=Leverandør bestill nektet
+Notify_ORDER_VALIDATE=Kundeordre validert
+Notify_PROPAL_VALIDATE=Kunden forslaget validert
PredefinedMailTest=Dette er en test post. \ NDe to linjer er atskilt med en vognretur.
PredefinedMailTestHtml=Dette er en test mail (ordet testen må være i fet skrift).
De to linjene er skilt med en vognretur.
FeatureNotYetAvailableShort=Tilgjengelig i en neste versjon
@@ -222,8 +222,8 @@ CurrentInformationOnImage=Informasjon om gjeldende bilde
YouReceiveMailBecauseOfNotification=Du mottar denne meldingen fordi din e-post har blitt lagt til listen over mål for å bli informert om spesielle hendelser i %s programvare av %s.
YouReceiveMailBecauseOfNotification2=Denne hendelsen er følgende:
ExternalSites=Eksterne nettsteder
-Notify_NOTIFY_VAL_ORDER=Bestelling van de klant gevalideerd
-Notify_NOTIFY_VAL_PROPAL=Klant voorstel gevalideerd
+Notify_ORDER_VALIDATE=Bestelling van de klant gevalideerd
+Notify_PROPAL_VALIDATE=Klant voorstel gevalideerd
PredefinedMailTest=Dit is een test e-mail. \ NDe twee lijnen worden gescheiden door een harde return.
PredefinedMailTestHtml=Dit is een test e-mail (het woord test moet worden in het vet).
De twee lijnen worden gescheiden door een harde return.
CalculatedWeight=Berekend gewicht
@@ -253,8 +253,8 @@ CalculatedWeight=Berekend gewicht
CalculatedVolume=Berekende volume
YouReceiveMailBecauseOfNotification=U ontvangt dit bericht omdat uw e-mail is toegevoegd aan de lijst van doelstellingen te worden geïnformeerd over bepaalde gebeurtenissen in de software van sssss sssss.
YouReceiveMailBecauseOfNotification2=Dit evenement is de volgende:
-Notify_NOTIFY_VAL_ORDER=Aby Klient zatwierdzone
-Notify_NOTIFY_VAL_PROPAL=wniosek Klienta zatwierdzone
+Notify_ORDER_VALIDATE=Aby Klient zatwierdzone
+Notify_PROPAL_VALIDATE=wniosek Klienta zatwierdzone
PredefinedMailTest=To jest test mail. Czeka na zatwierdzenie nowego dwie linie oddzielone są znakiem powrotu karetki.
PredefinedMailTestHtml=To jest mail do badań (test słowa muszą być pogrubione).
Dwie linie oddzielone są znakiem powrotu karetki.
CalculatedWeight=Oblicza masy
@@ -281,8 +281,8 @@ CurrentInformationOnImage=Informacje na temat bieżącego obrazu
YouReceiveMailBecauseOfNotification=Pojawieniu się tego komunikatu, ponieważ e-mail został dodany do listy celów do informacji o wydarzeniach w szczególności z sssss sssss oprogramowania.
YouReceiveMailBecauseOfNotification2=To wydarzenie jest następujące:
ExternalSites=tereny zewnętrzne
-Notify_NOTIFY_VAL_ORDER=ordem do cliente validado
-Notify_NOTIFY_VAL_PROPAL=proposta do cliente validado
+Notify_ORDER_VALIDATE=ordem do cliente validado
+Notify_PROPAL_VALIDATE=proposta do cliente validado
PredefinedMailTest=Este é um mail de teste. \ NO duas linhas são separadas por um retorno de carro.
PredefinedMailTestHtml=Este é um mail de teste (o teste da Palavra deve ser em negrito).
As duas linhas são separadas por um retorno de carro.
CalculatedWeight=peso calculado
@@ -308,8 +308,8 @@ CurrentInformationOnImage=Informações sobre a imagem atual
YouReceiveMailBecauseOfNotification=Você receberá esta mensagem porque seu e-mail foi adicionado à lista de alvos a ser informado dos acontecimentos em particular do software %s %s.
YouReceiveMailBecauseOfNotification2=Este evento é o seguinte:
ExternalSites=Sites externos
-Notify_NOTIFY_VAL_ORDER=Клиент для проверки
-Notify_NOTIFY_VAL_PROPAL=Клиент предложение проверки
+Notify_ORDER_VALIDATE=Клиент для проверки
+Notify_PROPAL_VALIDATE=Клиент предложение проверки
PredefinedMailTest=Это тест почты. \ NЭтот две строки, разделенные символом возврата каретки.
PredefinedMailTestHtml=Это тест почты (слово "испытание должно быть жирным шрифтом).
2 линии разделяются символом возврата каретки.
CalculatedWeight=Расчетный вес
@@ -336,8 +336,8 @@ CurrentInformationOnImage=Информация о текущем изображ
YouReceiveMailBecauseOfNotification=Это сообщение появляется, потому что ваше сообщение было добавлено в список целей, которые должны быть проинформированы о конкретных мероприятий в %s программного обеспечения %s.
YouReceiveMailBecauseOfNotification2=Это событие имеет следующий вид:
ExternalSites=На внешних сайтах
-Notify_NOTIFY_VAL_ORDER=Stranka da potrdijo
-Notify_NOTIFY_VAL_PROPAL=Customer predlogu potrjene
+Notify_ORDER_VALIDATE=Stranka da potrdijo
+Notify_PROPAL_VALIDATE=Customer predlogu potrjene
CalculatedWeight=Izračuna masa
CalculatedVolume=Izračuna prostornine
Length=Dolžina
@@ -361,8 +361,8 @@ CurrentInformationOnImage=Informacije o trenutni sliki
YouReceiveMailBecauseOfNotification=Prikaže se to sporočilo, ker je bil vaš e-poštni doda na seznam ciljev do obveščenosti določene prireditve v programsko opremo za %s %s.
YouReceiveMailBecauseOfNotification2=Ta dogodek je naslednji:
ExternalSites=Zunanjih spletnih mest
-Notify_NOTIFY_VAL_ORDER=Müşteri sipariş onaylandı
-Notify_NOTIFY_VAL_PROPAL=Müşteri öneri onaylandı
+Notify_ORDER_VALIDATE=Müşteri sipariş onaylandı
+Notify_PROPAL_VALIDATE=Müşteri öneri onaylandı
CalculatedWeight=Hesaplanan ağırlık
CalculatedVolume=Hesaplanan hacim
Length=Uzunluk
diff --git a/htdocs/langs/zh_CN/other.lang b/htdocs/langs/zh_CN/other.lang
index ea5ce55d16d..ab5f156dd20 100644
--- a/htdocs/langs/zh_CN/other.lang
+++ b/htdocs/langs/zh_CN/other.lang
@@ -33,12 +33,12 @@ BirthdayDate=生日
DateToBirth=在出生日期
BirthdayAlertOn=生日提醒活跃
BirthdayAlertOff=生日提醒无效
-Notify_NOTIFY_VAL_FICHINTER=验证干预
-Notify_NOTIFY_VAL_FAC=客户发票验证
-Notify_NOTIFY_APP_ORDER_SUPPLIER=供应商的订单批准
-Notify_NOTIFY_REF_ORDER_SUPPLIER=供应商的订单拒绝
-Notify_NOTIFY_VAL_ORDER=验证客户订单
-Notify_NOTIFY_VAL_PROPAL=验证客户的建议
+Notify_FICHINTER_VALIDATE=验证干预
+Notify_BILL_VALIDATE=客户发票验证
+Notify_ORDER_SUPPLIER_APPROVE=供应商的订单批准
+Notify_ORDER_SUPPLIER_REFUSE=供应商的订单拒绝
+Notify_ORDER_VALIDATE=验证客户订单
+Notify_PROPAL_VALIDATE=验证客户的建议
NbOfAttachedFiles=所附文件数/文件
TotalSizeOfAttachedFiles=所附文件的总大小/文件
MaxSize=最大尺寸
@@ -196,10 +196,10 @@ ExternalSites=外部网站
// Reference language: en_US
BirthdayAlertOn=bursdag varsling aktive
BirthdayAlertOff=bursdag varsling inaktive
-Notify_NOTIFY_APP_ORDER_SUPPLIER=Leverandør bestill godkjent
-Notify_NOTIFY_REF_ORDER_SUPPLIER=Leverandør bestill nektet
-Notify_NOTIFY_VAL_ORDER=Kundeordre validert
-Notify_NOTIFY_VAL_PROPAL=Kunden forslaget validert
+Notify_ORDER_SUPPLIER_APPROVE=Leverandør bestill godkjent
+Notify_ORDER_SUPPLIER_REFUSE=Leverandør bestill nektet
+Notify_ORDER_VALIDATE=Kundeordre validert
+Notify_PROPAL_VALIDATE=Kunden forslaget validert
PredefinedMailTest=Dette er en test post. \ NDe to linjer er atskilt med en vognretur.
PredefinedMailTestHtml=Dette er en test mail (ordet testen må være i fet skrift).
De to linjene er skilt med en vognretur.
FeatureNotYetAvailableShort=Tilgjengelig i en neste versjon
@@ -244,8 +244,8 @@ CurrentInformationOnImage=Informasjon om gjeldende bilde
YouReceiveMailBecauseOfNotification=Du mottar denne meldingen fordi din e-post har blitt lagt til listen over mål for å bli informert om spesielle hendelser i %s programvare av %s.
YouReceiveMailBecauseOfNotification2=Denne hendelsen er følgende:
ExternalSites=Eksterne nettsteder
-Notify_NOTIFY_VAL_ORDER=Bestelling van de klant gevalideerd
-Notify_NOTIFY_VAL_PROPAL=Klant voorstel gevalideerd
+Notify_ORDER_VALIDATE=Bestelling van de klant gevalideerd
+Notify_PROPAL_VALIDATE=Klant voorstel gevalideerd
PredefinedMailTest=Dit is een test e-mail. \ NDe twee lijnen worden gescheiden door een harde return.
PredefinedMailTestHtml=Dit is een test e-mail (het woord test moet worden in het vet).
De twee lijnen worden gescheiden door een harde return.
CalculatedWeight=Berekend gewicht
@@ -275,8 +275,8 @@ CalculatedWeight=Berekend gewicht
CalculatedVolume=Berekende volume
YouReceiveMailBecauseOfNotification=U ontvangt dit bericht omdat uw e-mail is toegevoegd aan de lijst van doelstellingen te worden geïnformeerd over bepaalde gebeurtenissen in de software van sssss sssss.
YouReceiveMailBecauseOfNotification2=Dit evenement is de volgende:
-Notify_NOTIFY_VAL_ORDER=Aby Klient zatwierdzone
-Notify_NOTIFY_VAL_PROPAL=wniosek Klienta zatwierdzone
+Notify_ORDER_VALIDATE=Aby Klient zatwierdzone
+Notify_PROPAL_VALIDATE=wniosek Klienta zatwierdzone
PredefinedMailTest=To jest test mail. Czeka na zatwierdzenie nowego dwie linie oddzielone są znakiem powrotu karetki.
PredefinedMailTestHtml=To jest mail do badań (test słowa muszą być pogrubione).
Dwie linie oddzielone są znakiem powrotu karetki.
CalculatedWeight=Oblicza masy
@@ -303,8 +303,8 @@ CurrentInformationOnImage=Informacje na temat bieżącego obrazu
YouReceiveMailBecauseOfNotification=Pojawieniu się tego komunikatu, ponieważ e-mail został dodany do listy celów do informacji o wydarzeniach w szczególności z sssss sssss oprogramowania.
YouReceiveMailBecauseOfNotification2=To wydarzenie jest następujące:
ExternalSites=tereny zewnętrzne
-Notify_NOTIFY_VAL_ORDER=ordem do cliente validado
-Notify_NOTIFY_VAL_PROPAL=proposta do cliente validado
+Notify_ORDER_VALIDATE=ordem do cliente validado
+Notify_PROPAL_VALIDATE=proposta do cliente validado
PredefinedMailTest=Este é um mail de teste. \ NO duas linhas são separadas por um retorno de carro.
PredefinedMailTestHtml=Este é um mail de teste (o teste da Palavra deve ser em negrito).
As duas linhas são separadas por um retorno de carro.
CalculatedWeight=peso calculado
@@ -330,8 +330,8 @@ CurrentInformationOnImage=Informações sobre a imagem atual
YouReceiveMailBecauseOfNotification=Você receberá esta mensagem porque seu e-mail foi adicionado à lista de alvos a ser informado dos acontecimentos em particular do software %s %s.
YouReceiveMailBecauseOfNotification2=Este evento é o seguinte:
ExternalSites=Sites externos
-Notify_NOTIFY_VAL_ORDER=Клиент для проверки
-Notify_NOTIFY_VAL_PROPAL=Клиент предложение проверки
+Notify_ORDER_VALIDATE=Клиент для проверки
+Notify_PROPAL_VALIDATE=Клиент предложение проверки
PredefinedMailTest=Это тест почты. \ NЭтот две строки, разделенные символом возврата каретки.
PredefinedMailTestHtml=Это тест почты (слово "испытание должно быть жирным шрифтом).
2 линии разделяются символом возврата каретки.
CalculatedWeight=Расчетный вес
@@ -358,8 +358,8 @@ CurrentInformationOnImage=Информация о текущем изображ
YouReceiveMailBecauseOfNotification=Это сообщение появляется, потому что ваше сообщение было добавлено в список целей, которые должны быть проинформированы о конкретных мероприятий в %s программного обеспечения %s.
YouReceiveMailBecauseOfNotification2=Это событие имеет следующий вид:
ExternalSites=На внешних сайтах
-Notify_NOTIFY_VAL_ORDER=Stranka da potrdijo
-Notify_NOTIFY_VAL_PROPAL=Customer predlogu potrjene
+Notify_ORDER_VALIDATE=Stranka da potrdijo
+Notify_PROPAL_VALIDATE=Customer predlogu potrjene
CalculatedWeight=Izračuna masa
CalculatedVolume=Izračuna prostornine
Length=Dolžina
@@ -383,8 +383,8 @@ CurrentInformationOnImage=Informacije o trenutni sliki
YouReceiveMailBecauseOfNotification=Prikaže se to sporočilo, ker je bil vaš e-poštni doda na seznam ciljev do obveščenosti določene prireditve v programsko opremo za %s %s.
YouReceiveMailBecauseOfNotification2=Ta dogodek je naslednji:
ExternalSites=Zunanjih spletnih mest
-Notify_NOTIFY_VAL_ORDER=Müşteri sipariş onaylandı
-Notify_NOTIFY_VAL_PROPAL=Müşteri öneri onaylandı
+Notify_ORDER_VALIDATE=Müşteri sipariş onaylandı
+Notify_PROPAL_VALIDATE=Müşteri öneri onaylandı
CalculatedWeight=Hesaplanan ağırlık
CalculatedVolume=Hesaplanan hacim
Length=Uzunluk
diff --git a/htdocs/societe/notify/fiche.php b/htdocs/societe/notify/fiche.php
index dc5dcf98b8e..cebbeaa5329 100644
--- a/htdocs/societe/notify/fiche.php
+++ b/htdocs/societe/notify/fiche.php
@@ -170,8 +170,10 @@ if ( $soc->fetch($soc->id) )
if (count($soc->thirdparty_and_contact_email_array()) > 0)
{
// Load array of notifications type available
- $sql = "SELECT a.rowid, a.code, a.titre";
- $sql.= " FROM ".MAIN_DB_PREFIX."action_def as a";
+ $sql = "SELECT a.rowid, a.code, a.label";
+ $sql.= " FROM ".MAIN_DB_PREFIX."c_action_trigger as a";
+ $sql.= " WHERE a.entity = ".$conf->entity;
+ $sql.= " AND a.active = 1";
$resql=$db->query($sql);
if ($resql)
@@ -181,8 +183,8 @@ if ( $soc->fetch($soc->id) )
while ($i < $num)
{
$obj = $db->fetch_object($resql);
- $libelle=($langs->trans("Notify_".$obj->code)!="Notify_".$obj->code?$langs->trans("Notify_".$obj->code):$obj->titre);
- $actions[$obj->rowid] = $libelle;
+ $label=($langs->trans("Notify_".$obj->code)!="Notify_".$obj->code?$langs->trans("Notify_".$obj->code):$obj->label);
+ $actions[$obj->rowid] = $label;
$i++;
}
@@ -235,11 +237,14 @@ if ( $soc->fetch($soc->id) )
// List of notifications for contacts
$sql = "SELECT n.rowid, n.type,";
- $sql.= " a.code, a.titre,";
- $sql.= " c.rowid as id, c.name, c.firstname, c.email";
- $sql.= " FROM ".MAIN_DB_PREFIX."action_def as a, ".MAIN_DB_PREFIX."notify_def as n,";
+ $sql.= " a.code, a.label,";
+ $sql.= " c.rowid as contactid, c.name, c.firstname, c.email";
+ $sql.= " FROM ".MAIN_DB_PREFIX."c_action_trigger as a,";
+ $sql.= " ".MAIN_DB_PREFIX."notify_def as n,";
$sql.= " ".MAIN_DB_PREFIX."socpeople c";
- $sql.= " WHERE a.rowid = n.fk_action AND c.rowid = n.fk_contact AND c.fk_soc = ".$soc->id;
+ $sql.= " WHERE a.rowid = n.fk_action";
+ $sql.= " AND c.rowid = n.fk_contact";
+ $sql.= " AND c.fk_soc = ".$soc->id;
$resql=$db->query($sql);
if ($resql)
@@ -255,7 +260,7 @@ if ( $soc->fetch($soc->id) )
$obj = $db->fetch_object($resql);
- $contactstatic->id=$obj->id;
+ $contactstatic->id=$obj->contactid;
$contactstatic->name=$obj->name;
$contactstatic->firstname=$obj->firstname;
print '| '.$contactstatic->getNomUrl(1);
@@ -273,8 +278,8 @@ if ( $soc->fetch($soc->id) )
}
print ' | ';
print '';
- $libelle=($langs->trans("Notify_".$obj->code)!="Notify_".$obj->code?$langs->trans("Notify_".$obj->code):$obj->titre);
- print $libelle;
+ $label=($langs->trans("Notify_".$obj->code)!="Notify_".$obj->code?$langs->trans("Notify_".$obj->code):$obj->label);
+ print $label;
print ' | ';
print '';
if ($obj->type == 'email') print $langs->trans("Email");
@@ -307,13 +312,16 @@ if ( $soc->fetch($soc->id) )
print_liste_field_titre($langs->trans("Date"),"fiche.php","a.titre",'',"&socid=$socid",'align="right"',$sortfield,$sortorder);
print ' |
';
- // Liste
+ // List
$sql = "SELECT n.rowid, n.daten, n.email, n.objet_type, n.objet_id,";
$sql.= " c.rowid as id, c.name, c.firstname, c.email,";
- $sql.= " a.code, a.titre";
- $sql.= " FROM ".MAIN_DB_PREFIX."action_def as a, ".MAIN_DB_PREFIX."notify as n, ";
+ $sql.= " a.code, a.label";
+ $sql.= " FROM ".MAIN_DB_PREFIX."c_action_trigger as a,";
+ $sql.= " ".MAIN_DB_PREFIX."notify as n, ";
$sql.= " ".MAIN_DB_PREFIX."socpeople as c";
- $sql.= " WHERE a.rowid = n.fk_action AND c.rowid = n.fk_contact AND c.fk_soc = ".$soc->id;
+ $sql.= " WHERE a.rowid = n.fk_action";
+ $sql.= " AND c.rowid = n.fk_contact";
+ $sql.= " AND c.fk_soc = ".$soc->id;
$resql=$db->query($sql);
if ($resql)
@@ -336,8 +344,8 @@ if ( $soc->fetch($soc->id) )
print $obj->email?' <'.$obj->email.'>':$langs->trans("NoMail");
print '';
print '';
- $libelle=($langs->trans("Notify_".$obj->code)!="Notify_".$obj->code?$langs->trans("Notify_".$obj->code):$obj->titre);
- print $libelle;
+ $label=($langs->trans("Notify_".$obj->code)!="Notify_".$obj->code?$langs->trans("Notify_".$obj->code):$obj->label);
+ print $label;
print ' | ';
// TODO Add link to object here
// print
diff --git a/htdocs/societe/notify/index.php b/htdocs/societe/notify/index.php
index 802f7759cd0..6b9836a0ac1 100644
--- a/htdocs/societe/notify/index.php
+++ b/htdocs/societe/notify/index.php
@@ -59,15 +59,19 @@ $pagenext = $page + 1;
llxHeader();
-$sql = "SELECT s.nom, s.rowid as socid, c.name, c.firstname, a.titre,n.rowid FROM ".MAIN_DB_PREFIX."socpeople as c, ".MAIN_DB_PREFIX."action_def as a, ".MAIN_DB_PREFIX."notify_def as n, ".MAIN_DB_PREFIX."societe as s";
-$sql .= " WHERE n.fk_contact = c.rowid AND a.rowid = n.fk_action";
-$sql .= " AND n.fk_soc = s.rowid";
-if ($socid > 0)
-{
- $sql .= " AND s.rowid = " . $user->societe_id;
-}
-$sql .= $db->order($sortfield,$sortorder);
-$sql .= $db->plimit($conf->liste_limit, $offset);
+$sql = "SELECT s.nom, s.rowid as socid, c.name, c.firstname, a.label, n.rowid";
+$sql.= " FROM ".MAIN_DB_PREFIX."socpeople as c,";
+$sql.= " ".MAIN_DB_PREFIX."c_action_trigger as a,";
+$sql.= " ".MAIN_DB_PREFIX."notify_def as n,";
+$sql.= " ".MAIN_DB_PREFIX."societe as s";
+$sql.= " WHERE n.fk_contact = c.rowid";
+$sql.= " AND a.rowid = n.fk_action";
+$sql.= " AND n.fk_soc = s.rowid";
+$sql.= " AND s.entity = ".$conf->entity;
+if ($socid > 0) $sql.= " AND s.rowid = " . $user->societe_id;
+
+$sql.= $db->order($sortfield,$sortorder);
+$sql.= $db->plimit($conf->liste_limit, $offset);
$result = $db->query($sql);
if ($result)
diff --git a/htdocs/core/class/notify.class.php b/htdocs/core/class/notify.class.php
index 05fc5274567..ab300f7892c 100644
--- a/htdocs/core/class/notify.class.php
+++ b/htdocs/core/class/notify.class.php
@@ -61,7 +61,7 @@ class Notify
/**
* \brief Renvoie le message signalant les notifications qui auront lieu sur
* un evenement pour affichage dans texte de confirmation evenement.
* \param action Id of action in llx_action_def
* \param socid Id of third party
* \return string Message
*/
@@ -79,20 +79,27 @@ class Notify
/**
* \brief Return number of notifications activated for action code and third party
* \param action Code of action in llx_action_def (new usage) or Id of action in llx_action_def (old usage)
* \param socid Id of third party
* \return int <0 si ko, sinon nombre de notifications definies
*/
function countDefinedNotifications($action,$socid)
{
+ global $conf;
+
$num=-1;
- $sql = "SELECT n.rowid, c.email, c.rowid, c.name, c.firstname, a.code, a.titre, s.nom";
- $sql.= " FROM ".MAIN_DB_PREFIX."socpeople as c, ".MAIN_DB_PREFIX."action_def as a, ".MAIN_DB_PREFIX."notify_def as n, ".MAIN_DB_PREFIX."societe as s";
- $sql.= " WHERE n.fk_contact = c.rowid AND a.rowid = n.fk_action";
+ $sql = "SELECT n.rowid";
+ $sql.= " FROM ".MAIN_DB_PREFIX."notify_def as n,";
+ $sql.= " ".MAIN_DB_PREFIX."socpeople as c,";
+ $sql.= " ".MAIN_DB_PREFIX."c_action_trigger as a,";
+ $sql.= " ".MAIN_DB_PREFIX."societe as s";
+ $sql.= " WHERE n.fk_contact = c.rowid";
+ $sql.= " AND a.rowid = n.fk_action";
$sql.= " AND n.fk_soc = s.rowid";
if (is_numeric($action)) $sql.= " AND n.fk_action = ".$action; // Old usage
else $sql.= " AND a.code = '".$action."'"; // New usage
+ $sql.= " AND a.entity = ".$conf->entity;
$sql.= " AND s.rowid = ".$socid;
dol_syslog("Notify.class::countDefinedNotifications $action, $socid");
@@ -114,7 +121,7 @@ class Notify
/**
* \brief Check if notification are active for couple action/company.
* If yes, send mail and save trace into llx_notify.
* \param action Code of action in llx_action_def (new usage) or Id of action in llx_action_def (old usage)
* \param socid Id of third party
* \param texte Message to send
* \param objet_type Type of object the notification deals on (facture, order, propal, order_supplier...). Just for log in llx_notify.
@@ -131,8 +138,11 @@ class Notify
dol_syslog("Notify::send action=$action, socid=$socid, texte=$texte, objet_type=$objet_type, objet_id=$objet_id, file=$file");
$sql = "SELECT s.nom, c.email, c.rowid as cid, c.name, c.firstname,";
- $sql.= " a.rowid as adid, a.titre, a.code, n.rowid";
- $sql.= " FROM ".MAIN_DB_PREFIX."socpeople as c, ".MAIN_DB_PREFIX."action_def as a, ".MAIN_DB_PREFIX."notify_def as n, ".MAIN_DB_PREFIX."societe as s";
+ $sql.= " a.rowid as adid, a.label, a.code, n.rowid";
+ $sql.= " FROM ".MAIN_DB_PREFIX."socpeople as c,";
+ $sql.= " ".MAIN_DB_PREFIX."c_action_trigger as a,";
+ $sql.= " ".MAIN_DB_PREFIX."notify_def as n,";
+ $sql.= " ".MAIN_DB_PREFIX."societe as s";
$sql.= " WHERE n.fk_contact = c.rowid AND a.rowid = n.fk_action";
$sql.= " AND n.fk_soc = s.rowid";
if (is_numeric($action)) $sql.= " AND n.fk_action = ".$action; // Old usage
@@ -61,7 +61,7 @@ class Notify
* \brief Renvoie le message signalant les notifications qui auront lieu sur
* un evenement pour affichage dans texte de confirmation evenement.
- * \param action Id of action in llx_action_def
+ * \param action Id of action in llx_c_action_trigger
* \param socid Id of third party
* \return string Message
@@ -79,20 +79,27 @@ class Notify
/**
* \brief Return number of notifications activated for action code and third party
- * \param action Code of action in llx_action_def (new usage) or Id of action in llx_action_def (old usage)
+ * \param action Code of action in llx_c_action_trigger (new usage) or Id of action in llx_c_action_trigger (old usage)
* \param socid Id of third party
* \return int <0 si ko, sinon nombre de notifications definies
@@ -114,7 +121,7 @@ class Notify
* \brief Check if notification are active for couple action/company.
* If yes, send mail and save trace into llx_notify.
- * \param action Code of action in llx_action_def (new usage) or Id of action in llx_action_def (old usage)
+ * \param action Code of action in llx_c_action_trigger (new usage) or Id of action in llx_c_action_trigger (old usage)
* \param socid Id of third party
* \param texte Message to send